journey

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the journey type in the database.
	Label = "journey"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldOrgID holds the string denoting the org_id field in the database.
	FieldOrgID = "org_id"
	// FieldProjectID holds the string denoting the project_id field in the database.
	FieldProjectID = "project_id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldDescription holds the string denoting the description field in the database.
	FieldDescription = "description"
	// FieldEntryConditions holds the string denoting the entry_conditions field in the database.
	FieldEntryConditions = "entry_conditions"
	// FieldExitConditions holds the string denoting the exit_conditions field in the database.
	FieldExitConditions = "exit_conditions"
	// FieldSteps holds the string denoting the steps field in the database.
	FieldSteps = "steps"
	// FieldTimeoutMinutes holds the string denoting the timeout_minutes field in the database.
	FieldTimeoutMinutes = "timeout_minutes"
	// FieldTotalSessions holds the string denoting the total_sessions field in the database.
	FieldTotalSessions = "total_sessions"
	// FieldConvertedSessions holds the string denoting the converted_sessions field in the database.
	FieldConvertedSessions = "converted_sessions"
	// FieldConversionRate holds the string denoting the conversion_rate field in the database.
	FieldConversionRate = "conversion_rate"
	// FieldAvgDurationMs holds the string denoting the avg_duration_ms field in the database.
	FieldAvgDurationMs = "avg_duration_ms"
	// FieldIsActive holds the string denoting the is_active field in the database.
	FieldIsActive = "is_active"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeProject holds the string denoting the project edge name in mutations.
	EdgeProject = "project"
	// EdgeEvents holds the string denoting the events edge name in mutations.
	EdgeEvents = "events"
	// EdgeSessions holds the string denoting the sessions edge name in mutations.
	EdgeSessions = "sessions"
	// Table holds the table name of the journey in the database.
	Table = "journeys"
	// ProjectTable is the table that holds the project relation/edge.
	ProjectTable = "journeys"
	// ProjectInverseTable is the table name for the Project entity.
	// It exists in this package in order to avoid circular dependency with the "project" package.
	ProjectInverseTable = "projects"
	// ProjectColumn is the table column denoting the project relation/edge.
	ProjectColumn = "project_id"
	// EventsTable is the table that holds the events relation/edge.
	EventsTable = "events"
	// EventsInverseTable is the table name for the Event entity.
	// It exists in this package in order to avoid circular dependency with the "event" package.
	EventsInverseTable = "events"
	// EventsColumn is the table column denoting the events relation/edge.
	EventsColumn = "journey_id"
	// SessionsTable is the table that holds the sessions relation/edge.
	SessionsTable = "sessions"
	// SessionsInverseTable is the table name for the Session entity.
	// It exists in this package in order to avoid circular dependency with the "session" package.
	SessionsInverseTable = "sessions"
	// SessionsColumn is the table column denoting the sessions relation/edge.
	SessionsColumn = "journey_id"
)

Variables

var (
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// DefaultTimeoutMinutes holds the default value on creation for the "timeout_minutes" field.
	DefaultTimeoutMinutes int
	// DefaultTotalSessions holds the default value on creation for the "total_sessions" field.
	DefaultTotalSessions int64
	// DefaultConvertedSessions holds the default value on creation for the "converted_sessions" field.
	DefaultConvertedSessions int64
	// DefaultConversionRate holds the default value on creation for the "conversion_rate" field.
	DefaultConversionRate float64
	// DefaultAvgDurationMs holds the default value on creation for the "avg_duration_ms" field.
	DefaultAvgDurationMs int64
	// DefaultIsActive holds the default value on creation for the "is_active" field.
	DefaultIsActive bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for journey fields.

Functions

func And

func And(predicates ...predicate.Journey) predicate.Journey

And groups predicates with the AND operator between them.

func AvgDurationMs

func AvgDurationMs(v int64) predicate.Journey

AvgDurationMs applies equality check predicate on the "avg_duration_ms" field. It's identical to AvgDurationMsEQ.

func AvgDurationMsEQ

func AvgDurationMsEQ(v int64) predicate.Journey

AvgDurationMsEQ applies the EQ predicate on the "avg_duration_ms" field.

func AvgDurationMsGT

func AvgDurationMsGT(v int64) predicate.Journey

AvgDurationMsGT applies the GT predicate on the "avg_duration_ms" field.

func AvgDurationMsGTE

func AvgDurationMsGTE(v int64) predicate.Journey

AvgDurationMsGTE applies the GTE predicate on the "avg_duration_ms" field.

func AvgDurationMsIn

func AvgDurationMsIn(vs ...int64) predicate.Journey

AvgDurationMsIn applies the In predicate on the "avg_duration_ms" field.

func AvgDurationMsLT

func AvgDurationMsLT(v int64) predicate.Journey

AvgDurationMsLT applies the LT predicate on the "avg_duration_ms" field.

func AvgDurationMsLTE

func AvgDurationMsLTE(v int64) predicate.Journey

AvgDurationMsLTE applies the LTE predicate on the "avg_duration_ms" field.

func AvgDurationMsNEQ

func AvgDurationMsNEQ(v int64) predicate.Journey

AvgDurationMsNEQ applies the NEQ predicate on the "avg_duration_ms" field.

func AvgDurationMsNotIn

func AvgDurationMsNotIn(vs ...int64) predicate.Journey

AvgDurationMsNotIn applies the NotIn predicate on the "avg_duration_ms" field.

func ConversionRate

func ConversionRate(v float64) predicate.Journey

ConversionRate applies equality check predicate on the "conversion_rate" field. It's identical to ConversionRateEQ.

func ConversionRateEQ

func ConversionRateEQ(v float64) predicate.Journey

ConversionRateEQ applies the EQ predicate on the "conversion_rate" field.

func ConversionRateGT

func ConversionRateGT(v float64) predicate.Journey

ConversionRateGT applies the GT predicate on the "conversion_rate" field.

func ConversionRateGTE

func ConversionRateGTE(v float64) predicate.Journey

ConversionRateGTE applies the GTE predicate on the "conversion_rate" field.

func ConversionRateIn

func ConversionRateIn(vs ...float64) predicate.Journey

ConversionRateIn applies the In predicate on the "conversion_rate" field.

func ConversionRateLT

func ConversionRateLT(v float64) predicate.Journey

ConversionRateLT applies the LT predicate on the "conversion_rate" field.

func ConversionRateLTE

func ConversionRateLTE(v float64) predicate.Journey

ConversionRateLTE applies the LTE predicate on the "conversion_rate" field.

func ConversionRateNEQ

func ConversionRateNEQ(v float64) predicate.Journey

ConversionRateNEQ applies the NEQ predicate on the "conversion_rate" field.

func ConversionRateNotIn

func ConversionRateNotIn(vs ...float64) predicate.Journey

ConversionRateNotIn applies the NotIn predicate on the "conversion_rate" field.

func ConvertedSessions

func ConvertedSessions(v int64) predicate.Journey

ConvertedSessions applies equality check predicate on the "converted_sessions" field. It's identical to ConvertedSessionsEQ.

func ConvertedSessionsEQ

func ConvertedSessionsEQ(v int64) predicate.Journey

ConvertedSessionsEQ applies the EQ predicate on the "converted_sessions" field.

func ConvertedSessionsGT

func ConvertedSessionsGT(v int64) predicate.Journey

ConvertedSessionsGT applies the GT predicate on the "converted_sessions" field.

func ConvertedSessionsGTE

func ConvertedSessionsGTE(v int64) predicate.Journey

ConvertedSessionsGTE applies the GTE predicate on the "converted_sessions" field.

func ConvertedSessionsIn

func ConvertedSessionsIn(vs ...int64) predicate.Journey

ConvertedSessionsIn applies the In predicate on the "converted_sessions" field.

func ConvertedSessionsLT

func ConvertedSessionsLT(v int64) predicate.Journey

ConvertedSessionsLT applies the LT predicate on the "converted_sessions" field.

func ConvertedSessionsLTE

func ConvertedSessionsLTE(v int64) predicate.Journey

ConvertedSessionsLTE applies the LTE predicate on the "converted_sessions" field.

func ConvertedSessionsNEQ

func ConvertedSessionsNEQ(v int64) predicate.Journey

ConvertedSessionsNEQ applies the NEQ predicate on the "converted_sessions" field.

func ConvertedSessionsNotIn

func ConvertedSessionsNotIn(vs ...int64) predicate.Journey

ConvertedSessionsNotIn applies the NotIn predicate on the "converted_sessions" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Journey

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Journey

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Journey

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Journey

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Journey

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Journey

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Journey

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Journey

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Journey

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Description

func Description(v string) predicate.Journey

Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.

func DescriptionContains

func DescriptionContains(v string) predicate.Journey

DescriptionContains applies the Contains predicate on the "description" field.

func DescriptionContainsFold

func DescriptionContainsFold(v string) predicate.Journey

DescriptionContainsFold applies the ContainsFold predicate on the "description" field.

func DescriptionEQ

func DescriptionEQ(v string) predicate.Journey

DescriptionEQ applies the EQ predicate on the "description" field.

func DescriptionEqualFold

func DescriptionEqualFold(v string) predicate.Journey

DescriptionEqualFold applies the EqualFold predicate on the "description" field.

func DescriptionGT

func DescriptionGT(v string) predicate.Journey

DescriptionGT applies the GT predicate on the "description" field.

func DescriptionGTE

func DescriptionGTE(v string) predicate.Journey

DescriptionGTE applies the GTE predicate on the "description" field.

func DescriptionHasPrefix

func DescriptionHasPrefix(v string) predicate.Journey

DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.

func DescriptionHasSuffix

func DescriptionHasSuffix(v string) predicate.Journey

DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.

func DescriptionIn

func DescriptionIn(vs ...string) predicate.Journey

DescriptionIn applies the In predicate on the "description" field.

func DescriptionIsNil

func DescriptionIsNil() predicate.Journey

DescriptionIsNil applies the IsNil predicate on the "description" field.

func DescriptionLT

func DescriptionLT(v string) predicate.Journey

DescriptionLT applies the LT predicate on the "description" field.

func DescriptionLTE

func DescriptionLTE(v string) predicate.Journey

DescriptionLTE applies the LTE predicate on the "description" field.

func DescriptionNEQ

func DescriptionNEQ(v string) predicate.Journey

DescriptionNEQ applies the NEQ predicate on the "description" field.

func DescriptionNotIn

func DescriptionNotIn(vs ...string) predicate.Journey

DescriptionNotIn applies the NotIn predicate on the "description" field.

func DescriptionNotNil

func DescriptionNotNil() predicate.Journey

DescriptionNotNil applies the NotNil predicate on the "description" field.

func EntryConditionsIsNil

func EntryConditionsIsNil() predicate.Journey

EntryConditionsIsNil applies the IsNil predicate on the "entry_conditions" field.

func EntryConditionsNotNil

func EntryConditionsNotNil() predicate.Journey

EntryConditionsNotNil applies the NotNil predicate on the "entry_conditions" field.

func ExitConditionsIsNil

func ExitConditionsIsNil() predicate.Journey

ExitConditionsIsNil applies the IsNil predicate on the "exit_conditions" field.

func ExitConditionsNotNil

func ExitConditionsNotNil() predicate.Journey

ExitConditionsNotNil applies the NotNil predicate on the "exit_conditions" field.

func HasEvents

func HasEvents() predicate.Journey

HasEvents applies the HasEdge predicate on the "events" edge.

func HasEventsWith

func HasEventsWith(preds ...predicate.Event) predicate.Journey

HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).

func HasProject

func HasProject() predicate.Journey

HasProject applies the HasEdge predicate on the "project" edge.

func HasProjectWith

func HasProjectWith(preds ...predicate.Project) predicate.Journey

HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).

func HasSessions

func HasSessions() predicate.Journey

HasSessions applies the HasEdge predicate on the "sessions" edge.

func HasSessionsWith

func HasSessionsWith(preds ...predicate.Session) predicate.Journey

HasSessionsWith applies the HasEdge predicate on the "sessions" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Journey

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Journey

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Journey

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Journey

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Journey

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Journey

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Journey

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Journey

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Journey

IDNotIn applies the NotIn predicate on the ID field.

func IsActive

func IsActive(v bool) predicate.Journey

IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.

func IsActiveEQ

func IsActiveEQ(v bool) predicate.Journey

IsActiveEQ applies the EQ predicate on the "is_active" field.

func IsActiveNEQ

func IsActiveNEQ(v bool) predicate.Journey

IsActiveNEQ applies the NEQ predicate on the "is_active" field.

func Name

func Name(v string) predicate.Journey

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Journey

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Journey

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Journey

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Journey

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Journey

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Journey

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Journey

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Journey

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Journey

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Journey

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Journey

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Journey

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Journey

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Journey) predicate.Journey

Or groups predicates with the OR operator between them.

func OrgID

func OrgID(v uuid.UUID) predicate.Journey

OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.

func OrgIDEQ

func OrgIDEQ(v uuid.UUID) predicate.Journey

OrgIDEQ applies the EQ predicate on the "org_id" field.

func OrgIDGT

func OrgIDGT(v uuid.UUID) predicate.Journey

OrgIDGT applies the GT predicate on the "org_id" field.

func OrgIDGTE

func OrgIDGTE(v uuid.UUID) predicate.Journey

OrgIDGTE applies the GTE predicate on the "org_id" field.

func OrgIDIn

func OrgIDIn(vs ...uuid.UUID) predicate.Journey

OrgIDIn applies the In predicate on the "org_id" field.

func OrgIDLT

func OrgIDLT(v uuid.UUID) predicate.Journey

OrgIDLT applies the LT predicate on the "org_id" field.

func OrgIDLTE

func OrgIDLTE(v uuid.UUID) predicate.Journey

OrgIDLTE applies the LTE predicate on the "org_id" field.

func OrgIDNEQ

func OrgIDNEQ(v uuid.UUID) predicate.Journey

OrgIDNEQ applies the NEQ predicate on the "org_id" field.

func OrgIDNotIn

func OrgIDNotIn(vs ...uuid.UUID) predicate.Journey

OrgIDNotIn applies the NotIn predicate on the "org_id" field.

func ProjectID

func ProjectID(v uuid.UUID) predicate.Journey

ProjectID applies equality check predicate on the "project_id" field. It's identical to ProjectIDEQ.

func ProjectIDEQ

func ProjectIDEQ(v uuid.UUID) predicate.Journey

ProjectIDEQ applies the EQ predicate on the "project_id" field.

func ProjectIDIn

func ProjectIDIn(vs ...uuid.UUID) predicate.Journey

ProjectIDIn applies the In predicate on the "project_id" field.

func ProjectIDNEQ

func ProjectIDNEQ(v uuid.UUID) predicate.Journey

ProjectIDNEQ applies the NEQ predicate on the "project_id" field.

func ProjectIDNotIn

func ProjectIDNotIn(vs ...uuid.UUID) predicate.Journey

ProjectIDNotIn applies the NotIn predicate on the "project_id" field.

func StepsIsNil

func StepsIsNil() predicate.Journey

StepsIsNil applies the IsNil predicate on the "steps" field.

func StepsNotNil

func StepsNotNil() predicate.Journey

StepsNotNil applies the NotNil predicate on the "steps" field.

func TimeoutMinutes

func TimeoutMinutes(v int) predicate.Journey

TimeoutMinutes applies equality check predicate on the "timeout_minutes" field. It's identical to TimeoutMinutesEQ.

func TimeoutMinutesEQ

func TimeoutMinutesEQ(v int) predicate.Journey

TimeoutMinutesEQ applies the EQ predicate on the "timeout_minutes" field.

func TimeoutMinutesGT

func TimeoutMinutesGT(v int) predicate.Journey

TimeoutMinutesGT applies the GT predicate on the "timeout_minutes" field.

func TimeoutMinutesGTE

func TimeoutMinutesGTE(v int) predicate.Journey

TimeoutMinutesGTE applies the GTE predicate on the "timeout_minutes" field.

func TimeoutMinutesIn

func TimeoutMinutesIn(vs ...int) predicate.Journey

TimeoutMinutesIn applies the In predicate on the "timeout_minutes" field.

func TimeoutMinutesLT

func TimeoutMinutesLT(v int) predicate.Journey

TimeoutMinutesLT applies the LT predicate on the "timeout_minutes" field.

func TimeoutMinutesLTE

func TimeoutMinutesLTE(v int) predicate.Journey

TimeoutMinutesLTE applies the LTE predicate on the "timeout_minutes" field.

func TimeoutMinutesNEQ

func TimeoutMinutesNEQ(v int) predicate.Journey

TimeoutMinutesNEQ applies the NEQ predicate on the "timeout_minutes" field.

func TimeoutMinutesNotIn

func TimeoutMinutesNotIn(vs ...int) predicate.Journey

TimeoutMinutesNotIn applies the NotIn predicate on the "timeout_minutes" field.

func TotalSessions

func TotalSessions(v int64) predicate.Journey

TotalSessions applies equality check predicate on the "total_sessions" field. It's identical to TotalSessionsEQ.

func TotalSessionsEQ

func TotalSessionsEQ(v int64) predicate.Journey

TotalSessionsEQ applies the EQ predicate on the "total_sessions" field.

func TotalSessionsGT

func TotalSessionsGT(v int64) predicate.Journey

TotalSessionsGT applies the GT predicate on the "total_sessions" field.

func TotalSessionsGTE

func TotalSessionsGTE(v int64) predicate.Journey

TotalSessionsGTE applies the GTE predicate on the "total_sessions" field.

func TotalSessionsIn

func TotalSessionsIn(vs ...int64) predicate.Journey

TotalSessionsIn applies the In predicate on the "total_sessions" field.

func TotalSessionsLT

func TotalSessionsLT(v int64) predicate.Journey

TotalSessionsLT applies the LT predicate on the "total_sessions" field.

func TotalSessionsLTE

func TotalSessionsLTE(v int64) predicate.Journey

TotalSessionsLTE applies the LTE predicate on the "total_sessions" field.

func TotalSessionsNEQ

func TotalSessionsNEQ(v int64) predicate.Journey

TotalSessionsNEQ applies the NEQ predicate on the "total_sessions" field.

func TotalSessionsNotIn

func TotalSessionsNotIn(vs ...int64) predicate.Journey

TotalSessionsNotIn applies the NotIn predicate on the "total_sessions" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Journey

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Journey

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Journey

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Journey

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Journey

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Journey

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Journey

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Journey

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Journey

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Journey queries.

func ByAvgDurationMs

func ByAvgDurationMs(opts ...sql.OrderTermOption) OrderOption

ByAvgDurationMs orders the results by the avg_duration_ms field.

func ByConversionRate

func ByConversionRate(opts ...sql.OrderTermOption) OrderOption

ByConversionRate orders the results by the conversion_rate field.

func ByConvertedSessions

func ByConvertedSessions(opts ...sql.OrderTermOption) OrderOption

ByConvertedSessions orders the results by the converted_sessions field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDescription

func ByDescription(opts ...sql.OrderTermOption) OrderOption

ByDescription orders the results by the description field.

func ByEvents

func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEvents orders the results by events terms.

func ByEventsCount

func ByEventsCount(opts ...sql.OrderTermOption) OrderOption

ByEventsCount orders the results by events count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIsActive

func ByIsActive(opts ...sql.OrderTermOption) OrderOption

ByIsActive orders the results by the is_active field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByOrgID

func ByOrgID(opts ...sql.OrderTermOption) OrderOption

ByOrgID orders the results by the org_id field.

func ByProjectField

func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption

ByProjectField orders the results by project field.

func ByProjectID

func ByProjectID(opts ...sql.OrderTermOption) OrderOption

ByProjectID orders the results by the project_id field.

func BySessions

func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

BySessions orders the results by sessions terms.

func BySessionsCount

func BySessionsCount(opts ...sql.OrderTermOption) OrderOption

BySessionsCount orders the results by sessions count.

func ByTimeoutMinutes

func ByTimeoutMinutes(opts ...sql.OrderTermOption) OrderOption

ByTimeoutMinutes orders the results by the timeout_minutes field.

func ByTotalSessions

func ByTotalSessions(opts ...sql.OrderTermOption) OrderOption

ByTotalSessions orders the results by the total_sessions field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

Jump to