project

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the project type in the database.
	Label = "project"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldOrgID holds the string denoting the org_id field in the database.
	FieldOrgID = "org_id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldSlug holds the string denoting the slug field in the database.
	FieldSlug = "slug"
	// FieldAPIKey holds the string denoting the api_key field in the database.
	FieldAPIKey = "api_key"
	// FieldSettings holds the string denoting the settings field in the database.
	FieldSettings = "settings"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeOrganization holds the string denoting the organization edge name in mutations.
	EdgeOrganization = "organization"
	// EdgeEvents holds the string denoting the events edge name in mutations.
	EdgeEvents = "events"
	// EdgeSessions holds the string denoting the sessions edge name in mutations.
	EdgeSessions = "sessions"
	// EdgeJourneys holds the string denoting the journeys edge name in mutations.
	EdgeJourneys = "journeys"
	// Table holds the table name of the project in the database.
	Table = "projects"
	// OrganizationTable is the table that holds the organization relation/edge.
	OrganizationTable = "projects"
	// OrganizationInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OrganizationInverseTable = "organizations"
	// OrganizationColumn is the table column denoting the organization relation/edge.
	OrganizationColumn = "org_id"
	// EventsTable is the table that holds the events relation/edge.
	EventsTable = "events"
	// EventsInverseTable is the table name for the Event entity.
	// It exists in this package in order to avoid circular dependency with the "event" package.
	EventsInverseTable = "events"
	// EventsColumn is the table column denoting the events relation/edge.
	EventsColumn = "project_id"
	// SessionsTable is the table that holds the sessions relation/edge.
	SessionsTable = "sessions"
	// SessionsInverseTable is the table name for the Session entity.
	// It exists in this package in order to avoid circular dependency with the "session" package.
	SessionsInverseTable = "sessions"
	// SessionsColumn is the table column denoting the sessions relation/edge.
	SessionsColumn = "project_id"
	// JourneysTable is the table that holds the journeys relation/edge.
	JourneysTable = "journeys"
	// JourneysInverseTable is the table name for the Journey entity.
	// It exists in this package in order to avoid circular dependency with the "journey" package.
	JourneysInverseTable = "journeys"
	// JourneysColumn is the table column denoting the journeys relation/edge.
	JourneysColumn = "project_id"
)

Variables

var (
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// SlugValidator is a validator for the "slug" field. It is called by the builders before save.
	SlugValidator func(string) error
	// APIKeyValidator is a validator for the "api_key" field. It is called by the builders before save.
	APIKeyValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for project fields.

Functions

func APIKey

func APIKey(v string) predicate.Project

APIKey applies equality check predicate on the "api_key" field. It's identical to APIKeyEQ.

func APIKeyContains

func APIKeyContains(v string) predicate.Project

APIKeyContains applies the Contains predicate on the "api_key" field.

func APIKeyContainsFold

func APIKeyContainsFold(v string) predicate.Project

APIKeyContainsFold applies the ContainsFold predicate on the "api_key" field.

func APIKeyEQ

func APIKeyEQ(v string) predicate.Project

APIKeyEQ applies the EQ predicate on the "api_key" field.

func APIKeyEqualFold

func APIKeyEqualFold(v string) predicate.Project

APIKeyEqualFold applies the EqualFold predicate on the "api_key" field.

func APIKeyGT

func APIKeyGT(v string) predicate.Project

APIKeyGT applies the GT predicate on the "api_key" field.

func APIKeyGTE

func APIKeyGTE(v string) predicate.Project

APIKeyGTE applies the GTE predicate on the "api_key" field.

func APIKeyHasPrefix

func APIKeyHasPrefix(v string) predicate.Project

APIKeyHasPrefix applies the HasPrefix predicate on the "api_key" field.

func APIKeyHasSuffix

func APIKeyHasSuffix(v string) predicate.Project

APIKeyHasSuffix applies the HasSuffix predicate on the "api_key" field.

func APIKeyIn

func APIKeyIn(vs ...string) predicate.Project

APIKeyIn applies the In predicate on the "api_key" field.

func APIKeyLT

func APIKeyLT(v string) predicate.Project

APIKeyLT applies the LT predicate on the "api_key" field.

func APIKeyLTE

func APIKeyLTE(v string) predicate.Project

APIKeyLTE applies the LTE predicate on the "api_key" field.

func APIKeyNEQ

func APIKeyNEQ(v string) predicate.Project

APIKeyNEQ applies the NEQ predicate on the "api_key" field.

func APIKeyNotIn

func APIKeyNotIn(vs ...string) predicate.Project

APIKeyNotIn applies the NotIn predicate on the "api_key" field.

func And

func And(predicates ...predicate.Project) predicate.Project

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Project

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Project

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Project

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Project

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Project

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Project

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Project

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Project

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Project

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasEvents

func HasEvents() predicate.Project

HasEvents applies the HasEdge predicate on the "events" edge.

func HasEventsWith

func HasEventsWith(preds ...predicate.Event) predicate.Project

HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).

func HasJourneys

func HasJourneys() predicate.Project

HasJourneys applies the HasEdge predicate on the "journeys" edge.

func HasJourneysWith

func HasJourneysWith(preds ...predicate.Journey) predicate.Project

HasJourneysWith applies the HasEdge predicate on the "journeys" edge with a given conditions (other predicates).

func HasOrganization

func HasOrganization() predicate.Project

HasOrganization applies the HasEdge predicate on the "organization" edge.

func HasOrganizationWith

func HasOrganizationWith(preds ...predicate.Organization) predicate.Project

HasOrganizationWith applies the HasEdge predicate on the "organization" edge with a given conditions (other predicates).

func HasSessions

func HasSessions() predicate.Project

HasSessions applies the HasEdge predicate on the "sessions" edge.

func HasSessionsWith

func HasSessionsWith(preds ...predicate.Session) predicate.Project

HasSessionsWith applies the HasEdge predicate on the "sessions" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Project

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Project

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Project

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Project

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Project

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Project

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Project

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Project

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Project

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Project

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Project

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Project

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Project

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Project

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Project

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Project

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Project

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Project

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Project

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Project

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Project

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Project

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Project

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Project) predicate.Project

Or groups predicates with the OR operator between them.

func OrgID

func OrgID(v uuid.UUID) predicate.Project

OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.

func OrgIDEQ

func OrgIDEQ(v uuid.UUID) predicate.Project

OrgIDEQ applies the EQ predicate on the "org_id" field.

func OrgIDIn

func OrgIDIn(vs ...uuid.UUID) predicate.Project

OrgIDIn applies the In predicate on the "org_id" field.

func OrgIDNEQ

func OrgIDNEQ(v uuid.UUID) predicate.Project

OrgIDNEQ applies the NEQ predicate on the "org_id" field.

func OrgIDNotIn

func OrgIDNotIn(vs ...uuid.UUID) predicate.Project

OrgIDNotIn applies the NotIn predicate on the "org_id" field.

func SettingsIsNil

func SettingsIsNil() predicate.Project

SettingsIsNil applies the IsNil predicate on the "settings" field.

func SettingsNotNil

func SettingsNotNil() predicate.Project

SettingsNotNil applies the NotNil predicate on the "settings" field.

func Slug

func Slug(v string) predicate.Project

Slug applies equality check predicate on the "slug" field. It's identical to SlugEQ.

func SlugContains

func SlugContains(v string) predicate.Project

SlugContains applies the Contains predicate on the "slug" field.

func SlugContainsFold

func SlugContainsFold(v string) predicate.Project

SlugContainsFold applies the ContainsFold predicate on the "slug" field.

func SlugEQ

func SlugEQ(v string) predicate.Project

SlugEQ applies the EQ predicate on the "slug" field.

func SlugEqualFold

func SlugEqualFold(v string) predicate.Project

SlugEqualFold applies the EqualFold predicate on the "slug" field.

func SlugGT

func SlugGT(v string) predicate.Project

SlugGT applies the GT predicate on the "slug" field.

func SlugGTE

func SlugGTE(v string) predicate.Project

SlugGTE applies the GTE predicate on the "slug" field.

func SlugHasPrefix

func SlugHasPrefix(v string) predicate.Project

SlugHasPrefix applies the HasPrefix predicate on the "slug" field.

func SlugHasSuffix

func SlugHasSuffix(v string) predicate.Project

SlugHasSuffix applies the HasSuffix predicate on the "slug" field.

func SlugIn

func SlugIn(vs ...string) predicate.Project

SlugIn applies the In predicate on the "slug" field.

func SlugLT

func SlugLT(v string) predicate.Project

SlugLT applies the LT predicate on the "slug" field.

func SlugLTE

func SlugLTE(v string) predicate.Project

SlugLTE applies the LTE predicate on the "slug" field.

func SlugNEQ

func SlugNEQ(v string) predicate.Project

SlugNEQ applies the NEQ predicate on the "slug" field.

func SlugNotIn

func SlugNotIn(vs ...string) predicate.Project

SlugNotIn applies the NotIn predicate on the "slug" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Project

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Project

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Project

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Project

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Project

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Project

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Project

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Project

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Project

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Project queries.

func ByAPIKey

func ByAPIKey(opts ...sql.OrderTermOption) OrderOption

ByAPIKey orders the results by the api_key field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByEvents

func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEvents orders the results by events terms.

func ByEventsCount

func ByEventsCount(opts ...sql.OrderTermOption) OrderOption

ByEventsCount orders the results by events count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByJourneys

func ByJourneys(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByJourneys orders the results by journeys terms.

func ByJourneysCount

func ByJourneysCount(opts ...sql.OrderTermOption) OrderOption

ByJourneysCount orders the results by journeys count.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByOrgID

func ByOrgID(opts ...sql.OrderTermOption) OrderOption

ByOrgID orders the results by the org_id field.

func ByOrganizationField

func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption

ByOrganizationField orders the results by organization field.

func BySessions

func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

BySessions orders the results by sessions terms.

func BySessionsCount

func BySessionsCount(opts ...sql.OrderTermOption) OrderOption

BySessionsCount orders the results by sessions count.

func BySlug

func BySlug(opts ...sql.OrderTermOption) OrderOption

BySlug orders the results by the slug field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

Jump to