session

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the session type in the database.
	Label = "session"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldOrgID holds the string denoting the org_id field in the database.
	FieldOrgID = "org_id"
	// FieldProjectID holds the string denoting the project_id field in the database.
	FieldProjectID = "project_id"
	// FieldSessionID holds the string denoting the session_id field in the database.
	FieldSessionID = "session_id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldStartedAt holds the string denoting the started_at field in the database.
	FieldStartedAt = "started_at"
	// FieldEndedAt holds the string denoting the ended_at field in the database.
	FieldEndedAt = "ended_at"
	// FieldDurationMs holds the string denoting the duration_ms field in the database.
	FieldDurationMs = "duration_ms"
	// FieldEntryPage holds the string denoting the entry_page field in the database.
	FieldEntryPage = "entry_page"
	// FieldExitPage holds the string denoting the exit_page field in the database.
	FieldExitPage = "exit_page"
	// FieldPageCount holds the string denoting the page_count field in the database.
	FieldPageCount = "page_count"
	// FieldEventCount holds the string denoting the event_count field in the database.
	FieldEventCount = "event_count"
	// FieldJourneyID holds the string denoting the journey_id field in the database.
	FieldJourneyID = "journey_id"
	// FieldLastJourneyStepID holds the string denoting the last_journey_step_id field in the database.
	FieldLastJourneyStepID = "last_journey_step_id"
	// FieldConversionStatus holds the string denoting the conversion_status field in the database.
	FieldConversionStatus = "conversion_status"
	// FieldUserAgent holds the string denoting the user_agent field in the database.
	FieldUserAgent = "user_agent"
	// FieldDeviceType holds the string denoting the device_type field in the database.
	FieldDeviceType = "device_type"
	// FieldBrowser holds the string denoting the browser field in the database.
	FieldBrowser = "browser"
	// FieldOs holds the string denoting the os field in the database.
	FieldOs = "os"
	// FieldCountry holds the string denoting the country field in the database.
	FieldCountry = "country"
	// FieldRegion holds the string denoting the region field in the database.
	FieldRegion = "region"
	// FieldCity holds the string denoting the city field in the database.
	FieldCity = "city"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeProject holds the string denoting the project edge name in mutations.
	EdgeProject = "project"
	// EdgeJourney holds the string denoting the journey edge name in mutations.
	EdgeJourney = "journey"
	// Table holds the table name of the session in the database.
	Table = "sessions"
	// ProjectTable is the table that holds the project relation/edge.
	ProjectTable = "sessions"
	// ProjectInverseTable is the table name for the Project entity.
	// It exists in this package in order to avoid circular dependency with the "project" package.
	ProjectInverseTable = "projects"
	// ProjectColumn is the table column denoting the project relation/edge.
	ProjectColumn = "project_id"
	// JourneyTable is the table that holds the journey relation/edge.
	JourneyTable = "sessions"
	// JourneyInverseTable is the table name for the Journey entity.
	// It exists in this package in order to avoid circular dependency with the "journey" package.
	JourneyInverseTable = "journeys"
	// JourneyColumn is the table column denoting the journey relation/edge.
	JourneyColumn = "journey_id"
)

Variables

var (
	// SessionIDValidator is a validator for the "session_id" field. It is called by the builders before save.
	SessionIDValidator func(string) error
	// UserIDValidator is a validator for the "user_id" field. It is called by the builders before save.
	UserIDValidator func(string) error
	// DefaultDurationMs holds the default value on creation for the "duration_ms" field.
	DefaultDurationMs int64
	// EntryPageValidator is a validator for the "entry_page" field. It is called by the builders before save.
	EntryPageValidator func(string) error
	// ExitPageValidator is a validator for the "exit_page" field. It is called by the builders before save.
	ExitPageValidator func(string) error
	// DefaultPageCount holds the default value on creation for the "page_count" field.
	DefaultPageCount int
	// DefaultEventCount holds the default value on creation for the "event_count" field.
	DefaultEventCount int
	// LastJourneyStepIDValidator is a validator for the "last_journey_step_id" field. It is called by the builders before save.
	LastJourneyStepIDValidator func(string) error
	// ConversionStatusValidator is a validator for the "conversion_status" field. It is called by the builders before save.
	ConversionStatusValidator func(string) error
	// UserAgentValidator is a validator for the "user_agent" field. It is called by the builders before save.
	UserAgentValidator func(string) error
	// DeviceTypeValidator is a validator for the "device_type" field. It is called by the builders before save.
	DeviceTypeValidator func(string) error
	// BrowserValidator is a validator for the "browser" field. It is called by the builders before save.
	BrowserValidator func(string) error
	// OsValidator is a validator for the "os" field. It is called by the builders before save.
	OsValidator func(string) error
	// CountryValidator is a validator for the "country" field. It is called by the builders before save.
	CountryValidator func(string) error
	// RegionValidator is a validator for the "region" field. It is called by the builders before save.
	RegionValidator func(string) error
	// CityValidator is a validator for the "city" field. It is called by the builders before save.
	CityValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for session fields.

Functions

func And

func And(predicates ...predicate.Session) predicate.Session

And groups predicates with the AND operator between them.

func Browser

func Browser(v string) predicate.Session

Browser applies equality check predicate on the "browser" field. It's identical to BrowserEQ.

func BrowserContains

func BrowserContains(v string) predicate.Session

BrowserContains applies the Contains predicate on the "browser" field.

func BrowserContainsFold

func BrowserContainsFold(v string) predicate.Session

BrowserContainsFold applies the ContainsFold predicate on the "browser" field.

func BrowserEQ

func BrowserEQ(v string) predicate.Session

BrowserEQ applies the EQ predicate on the "browser" field.

func BrowserEqualFold

func BrowserEqualFold(v string) predicate.Session

BrowserEqualFold applies the EqualFold predicate on the "browser" field.

func BrowserGT

func BrowserGT(v string) predicate.Session

BrowserGT applies the GT predicate on the "browser" field.

func BrowserGTE

func BrowserGTE(v string) predicate.Session

BrowserGTE applies the GTE predicate on the "browser" field.

func BrowserHasPrefix

func BrowserHasPrefix(v string) predicate.Session

BrowserHasPrefix applies the HasPrefix predicate on the "browser" field.

func BrowserHasSuffix

func BrowserHasSuffix(v string) predicate.Session

BrowserHasSuffix applies the HasSuffix predicate on the "browser" field.

func BrowserIn

func BrowserIn(vs ...string) predicate.Session

BrowserIn applies the In predicate on the "browser" field.

func BrowserIsNil

func BrowserIsNil() predicate.Session

BrowserIsNil applies the IsNil predicate on the "browser" field.

func BrowserLT

func BrowserLT(v string) predicate.Session

BrowserLT applies the LT predicate on the "browser" field.

func BrowserLTE

func BrowserLTE(v string) predicate.Session

BrowserLTE applies the LTE predicate on the "browser" field.

func BrowserNEQ

func BrowserNEQ(v string) predicate.Session

BrowserNEQ applies the NEQ predicate on the "browser" field.

func BrowserNotIn

func BrowserNotIn(vs ...string) predicate.Session

BrowserNotIn applies the NotIn predicate on the "browser" field.

func BrowserNotNil

func BrowserNotNil() predicate.Session

BrowserNotNil applies the NotNil predicate on the "browser" field.

func City

func City(v string) predicate.Session

City applies equality check predicate on the "city" field. It's identical to CityEQ.

func CityContains

func CityContains(v string) predicate.Session

CityContains applies the Contains predicate on the "city" field.

func CityContainsFold

func CityContainsFold(v string) predicate.Session

CityContainsFold applies the ContainsFold predicate on the "city" field.

func CityEQ

func CityEQ(v string) predicate.Session

CityEQ applies the EQ predicate on the "city" field.

func CityEqualFold

func CityEqualFold(v string) predicate.Session

CityEqualFold applies the EqualFold predicate on the "city" field.

func CityGT

func CityGT(v string) predicate.Session

CityGT applies the GT predicate on the "city" field.

func CityGTE

func CityGTE(v string) predicate.Session

CityGTE applies the GTE predicate on the "city" field.

func CityHasPrefix

func CityHasPrefix(v string) predicate.Session

CityHasPrefix applies the HasPrefix predicate on the "city" field.

func CityHasSuffix

func CityHasSuffix(v string) predicate.Session

CityHasSuffix applies the HasSuffix predicate on the "city" field.

func CityIn

func CityIn(vs ...string) predicate.Session

CityIn applies the In predicate on the "city" field.

func CityIsNil

func CityIsNil() predicate.Session

CityIsNil applies the IsNil predicate on the "city" field.

func CityLT

func CityLT(v string) predicate.Session

CityLT applies the LT predicate on the "city" field.

func CityLTE

func CityLTE(v string) predicate.Session

CityLTE applies the LTE predicate on the "city" field.

func CityNEQ

func CityNEQ(v string) predicate.Session

CityNEQ applies the NEQ predicate on the "city" field.

func CityNotIn

func CityNotIn(vs ...string) predicate.Session

CityNotIn applies the NotIn predicate on the "city" field.

func CityNotNil

func CityNotNil() predicate.Session

CityNotNil applies the NotNil predicate on the "city" field.

func ConversionStatus

func ConversionStatus(v string) predicate.Session

ConversionStatus applies equality check predicate on the "conversion_status" field. It's identical to ConversionStatusEQ.

func ConversionStatusContains

func ConversionStatusContains(v string) predicate.Session

ConversionStatusContains applies the Contains predicate on the "conversion_status" field.

func ConversionStatusContainsFold

func ConversionStatusContainsFold(v string) predicate.Session

ConversionStatusContainsFold applies the ContainsFold predicate on the "conversion_status" field.

func ConversionStatusEQ

func ConversionStatusEQ(v string) predicate.Session

ConversionStatusEQ applies the EQ predicate on the "conversion_status" field.

func ConversionStatusEqualFold

func ConversionStatusEqualFold(v string) predicate.Session

ConversionStatusEqualFold applies the EqualFold predicate on the "conversion_status" field.

func ConversionStatusGT

func ConversionStatusGT(v string) predicate.Session

ConversionStatusGT applies the GT predicate on the "conversion_status" field.

func ConversionStatusGTE

func ConversionStatusGTE(v string) predicate.Session

ConversionStatusGTE applies the GTE predicate on the "conversion_status" field.

func ConversionStatusHasPrefix

func ConversionStatusHasPrefix(v string) predicate.Session

ConversionStatusHasPrefix applies the HasPrefix predicate on the "conversion_status" field.

func ConversionStatusHasSuffix

func ConversionStatusHasSuffix(v string) predicate.Session

ConversionStatusHasSuffix applies the HasSuffix predicate on the "conversion_status" field.

func ConversionStatusIn

func ConversionStatusIn(vs ...string) predicate.Session

ConversionStatusIn applies the In predicate on the "conversion_status" field.

func ConversionStatusIsNil

func ConversionStatusIsNil() predicate.Session

ConversionStatusIsNil applies the IsNil predicate on the "conversion_status" field.

func ConversionStatusLT

func ConversionStatusLT(v string) predicate.Session

ConversionStatusLT applies the LT predicate on the "conversion_status" field.

func ConversionStatusLTE

func ConversionStatusLTE(v string) predicate.Session

ConversionStatusLTE applies the LTE predicate on the "conversion_status" field.

func ConversionStatusNEQ

func ConversionStatusNEQ(v string) predicate.Session

ConversionStatusNEQ applies the NEQ predicate on the "conversion_status" field.

func ConversionStatusNotIn

func ConversionStatusNotIn(vs ...string) predicate.Session

ConversionStatusNotIn applies the NotIn predicate on the "conversion_status" field.

func ConversionStatusNotNil

func ConversionStatusNotNil() predicate.Session

ConversionStatusNotNil applies the NotNil predicate on the "conversion_status" field.

func Country

func Country(v string) predicate.Session

Country applies equality check predicate on the "country" field. It's identical to CountryEQ.

func CountryContains

func CountryContains(v string) predicate.Session

CountryContains applies the Contains predicate on the "country" field.

func CountryContainsFold

func CountryContainsFold(v string) predicate.Session

CountryContainsFold applies the ContainsFold predicate on the "country" field.

func CountryEQ

func CountryEQ(v string) predicate.Session

CountryEQ applies the EQ predicate on the "country" field.

func CountryEqualFold

func CountryEqualFold(v string) predicate.Session

CountryEqualFold applies the EqualFold predicate on the "country" field.

func CountryGT

func CountryGT(v string) predicate.Session

CountryGT applies the GT predicate on the "country" field.

func CountryGTE

func CountryGTE(v string) predicate.Session

CountryGTE applies the GTE predicate on the "country" field.

func CountryHasPrefix

func CountryHasPrefix(v string) predicate.Session

CountryHasPrefix applies the HasPrefix predicate on the "country" field.

func CountryHasSuffix

func CountryHasSuffix(v string) predicate.Session

CountryHasSuffix applies the HasSuffix predicate on the "country" field.

func CountryIn

func CountryIn(vs ...string) predicate.Session

CountryIn applies the In predicate on the "country" field.

func CountryIsNil

func CountryIsNil() predicate.Session

CountryIsNil applies the IsNil predicate on the "country" field.

func CountryLT

func CountryLT(v string) predicate.Session

CountryLT applies the LT predicate on the "country" field.

func CountryLTE

func CountryLTE(v string) predicate.Session

CountryLTE applies the LTE predicate on the "country" field.

func CountryNEQ

func CountryNEQ(v string) predicate.Session

CountryNEQ applies the NEQ predicate on the "country" field.

func CountryNotIn

func CountryNotIn(vs ...string) predicate.Session

CountryNotIn applies the NotIn predicate on the "country" field.

func CountryNotNil

func CountryNotNil() predicate.Session

CountryNotNil applies the NotNil predicate on the "country" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Session

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Session

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Session

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Session

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Session

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Session

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Session

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Session

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Session

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DeviceType

func DeviceType(v string) predicate.Session

DeviceType applies equality check predicate on the "device_type" field. It's identical to DeviceTypeEQ.

func DeviceTypeContains

func DeviceTypeContains(v string) predicate.Session

DeviceTypeContains applies the Contains predicate on the "device_type" field.

func DeviceTypeContainsFold

func DeviceTypeContainsFold(v string) predicate.Session

DeviceTypeContainsFold applies the ContainsFold predicate on the "device_type" field.

func DeviceTypeEQ

func DeviceTypeEQ(v string) predicate.Session

DeviceTypeEQ applies the EQ predicate on the "device_type" field.

func DeviceTypeEqualFold

func DeviceTypeEqualFold(v string) predicate.Session

DeviceTypeEqualFold applies the EqualFold predicate on the "device_type" field.

func DeviceTypeGT

func DeviceTypeGT(v string) predicate.Session

DeviceTypeGT applies the GT predicate on the "device_type" field.

func DeviceTypeGTE

func DeviceTypeGTE(v string) predicate.Session

DeviceTypeGTE applies the GTE predicate on the "device_type" field.

func DeviceTypeHasPrefix

func DeviceTypeHasPrefix(v string) predicate.Session

DeviceTypeHasPrefix applies the HasPrefix predicate on the "device_type" field.

func DeviceTypeHasSuffix

func DeviceTypeHasSuffix(v string) predicate.Session

DeviceTypeHasSuffix applies the HasSuffix predicate on the "device_type" field.

func DeviceTypeIn

func DeviceTypeIn(vs ...string) predicate.Session

DeviceTypeIn applies the In predicate on the "device_type" field.

func DeviceTypeIsNil

func DeviceTypeIsNil() predicate.Session

DeviceTypeIsNil applies the IsNil predicate on the "device_type" field.

func DeviceTypeLT

func DeviceTypeLT(v string) predicate.Session

DeviceTypeLT applies the LT predicate on the "device_type" field.

func DeviceTypeLTE

func DeviceTypeLTE(v string) predicate.Session

DeviceTypeLTE applies the LTE predicate on the "device_type" field.

func DeviceTypeNEQ

func DeviceTypeNEQ(v string) predicate.Session

DeviceTypeNEQ applies the NEQ predicate on the "device_type" field.

func DeviceTypeNotIn

func DeviceTypeNotIn(vs ...string) predicate.Session

DeviceTypeNotIn applies the NotIn predicate on the "device_type" field.

func DeviceTypeNotNil

func DeviceTypeNotNil() predicate.Session

DeviceTypeNotNil applies the NotNil predicate on the "device_type" field.

func DurationMs

func DurationMs(v int64) predicate.Session

DurationMs applies equality check predicate on the "duration_ms" field. It's identical to DurationMsEQ.

func DurationMsEQ

func DurationMsEQ(v int64) predicate.Session

DurationMsEQ applies the EQ predicate on the "duration_ms" field.

func DurationMsGT

func DurationMsGT(v int64) predicate.Session

DurationMsGT applies the GT predicate on the "duration_ms" field.

func DurationMsGTE

func DurationMsGTE(v int64) predicate.Session

DurationMsGTE applies the GTE predicate on the "duration_ms" field.

func DurationMsIn

func DurationMsIn(vs ...int64) predicate.Session

DurationMsIn applies the In predicate on the "duration_ms" field.

func DurationMsLT

func DurationMsLT(v int64) predicate.Session

DurationMsLT applies the LT predicate on the "duration_ms" field.

func DurationMsLTE

func DurationMsLTE(v int64) predicate.Session

DurationMsLTE applies the LTE predicate on the "duration_ms" field.

func DurationMsNEQ

func DurationMsNEQ(v int64) predicate.Session

DurationMsNEQ applies the NEQ predicate on the "duration_ms" field.

func DurationMsNotIn

func DurationMsNotIn(vs ...int64) predicate.Session

DurationMsNotIn applies the NotIn predicate on the "duration_ms" field.

func EndedAt

func EndedAt(v time.Time) predicate.Session

EndedAt applies equality check predicate on the "ended_at" field. It's identical to EndedAtEQ.

func EndedAtEQ

func EndedAtEQ(v time.Time) predicate.Session

EndedAtEQ applies the EQ predicate on the "ended_at" field.

func EndedAtGT

func EndedAtGT(v time.Time) predicate.Session

EndedAtGT applies the GT predicate on the "ended_at" field.

func EndedAtGTE

func EndedAtGTE(v time.Time) predicate.Session

EndedAtGTE applies the GTE predicate on the "ended_at" field.

func EndedAtIn

func EndedAtIn(vs ...time.Time) predicate.Session

EndedAtIn applies the In predicate on the "ended_at" field.

func EndedAtIsNil

func EndedAtIsNil() predicate.Session

EndedAtIsNil applies the IsNil predicate on the "ended_at" field.

func EndedAtLT

func EndedAtLT(v time.Time) predicate.Session

EndedAtLT applies the LT predicate on the "ended_at" field.

func EndedAtLTE

func EndedAtLTE(v time.Time) predicate.Session

EndedAtLTE applies the LTE predicate on the "ended_at" field.

func EndedAtNEQ

func EndedAtNEQ(v time.Time) predicate.Session

EndedAtNEQ applies the NEQ predicate on the "ended_at" field.

func EndedAtNotIn

func EndedAtNotIn(vs ...time.Time) predicate.Session

EndedAtNotIn applies the NotIn predicate on the "ended_at" field.

func EndedAtNotNil

func EndedAtNotNil() predicate.Session

EndedAtNotNil applies the NotNil predicate on the "ended_at" field.

func EntryPage

func EntryPage(v string) predicate.Session

EntryPage applies equality check predicate on the "entry_page" field. It's identical to EntryPageEQ.

func EntryPageContains

func EntryPageContains(v string) predicate.Session

EntryPageContains applies the Contains predicate on the "entry_page" field.

func EntryPageContainsFold

func EntryPageContainsFold(v string) predicate.Session

EntryPageContainsFold applies the ContainsFold predicate on the "entry_page" field.

func EntryPageEQ

func EntryPageEQ(v string) predicate.Session

EntryPageEQ applies the EQ predicate on the "entry_page" field.

func EntryPageEqualFold

func EntryPageEqualFold(v string) predicate.Session

EntryPageEqualFold applies the EqualFold predicate on the "entry_page" field.

func EntryPageGT

func EntryPageGT(v string) predicate.Session

EntryPageGT applies the GT predicate on the "entry_page" field.

func EntryPageGTE

func EntryPageGTE(v string) predicate.Session

EntryPageGTE applies the GTE predicate on the "entry_page" field.

func EntryPageHasPrefix

func EntryPageHasPrefix(v string) predicate.Session

EntryPageHasPrefix applies the HasPrefix predicate on the "entry_page" field.

func EntryPageHasSuffix

func EntryPageHasSuffix(v string) predicate.Session

EntryPageHasSuffix applies the HasSuffix predicate on the "entry_page" field.

func EntryPageIn

func EntryPageIn(vs ...string) predicate.Session

EntryPageIn applies the In predicate on the "entry_page" field.

func EntryPageIsNil

func EntryPageIsNil() predicate.Session

EntryPageIsNil applies the IsNil predicate on the "entry_page" field.

func EntryPageLT

func EntryPageLT(v string) predicate.Session

EntryPageLT applies the LT predicate on the "entry_page" field.

func EntryPageLTE

func EntryPageLTE(v string) predicate.Session

EntryPageLTE applies the LTE predicate on the "entry_page" field.

func EntryPageNEQ

func EntryPageNEQ(v string) predicate.Session

EntryPageNEQ applies the NEQ predicate on the "entry_page" field.

func EntryPageNotIn

func EntryPageNotIn(vs ...string) predicate.Session

EntryPageNotIn applies the NotIn predicate on the "entry_page" field.

func EntryPageNotNil

func EntryPageNotNil() predicate.Session

EntryPageNotNil applies the NotNil predicate on the "entry_page" field.

func EventCount

func EventCount(v int) predicate.Session

EventCount applies equality check predicate on the "event_count" field. It's identical to EventCountEQ.

func EventCountEQ

func EventCountEQ(v int) predicate.Session

EventCountEQ applies the EQ predicate on the "event_count" field.

func EventCountGT

func EventCountGT(v int) predicate.Session

EventCountGT applies the GT predicate on the "event_count" field.

func EventCountGTE

func EventCountGTE(v int) predicate.Session

EventCountGTE applies the GTE predicate on the "event_count" field.

func EventCountIn

func EventCountIn(vs ...int) predicate.Session

EventCountIn applies the In predicate on the "event_count" field.

func EventCountLT

func EventCountLT(v int) predicate.Session

EventCountLT applies the LT predicate on the "event_count" field.

func EventCountLTE

func EventCountLTE(v int) predicate.Session

EventCountLTE applies the LTE predicate on the "event_count" field.

func EventCountNEQ

func EventCountNEQ(v int) predicate.Session

EventCountNEQ applies the NEQ predicate on the "event_count" field.

func EventCountNotIn

func EventCountNotIn(vs ...int) predicate.Session

EventCountNotIn applies the NotIn predicate on the "event_count" field.

func ExitPage

func ExitPage(v string) predicate.Session

ExitPage applies equality check predicate on the "exit_page" field. It's identical to ExitPageEQ.

func ExitPageContains

func ExitPageContains(v string) predicate.Session

ExitPageContains applies the Contains predicate on the "exit_page" field.

func ExitPageContainsFold

func ExitPageContainsFold(v string) predicate.Session

ExitPageContainsFold applies the ContainsFold predicate on the "exit_page" field.

func ExitPageEQ

func ExitPageEQ(v string) predicate.Session

ExitPageEQ applies the EQ predicate on the "exit_page" field.

func ExitPageEqualFold

func ExitPageEqualFold(v string) predicate.Session

ExitPageEqualFold applies the EqualFold predicate on the "exit_page" field.

func ExitPageGT

func ExitPageGT(v string) predicate.Session

ExitPageGT applies the GT predicate on the "exit_page" field.

func ExitPageGTE

func ExitPageGTE(v string) predicate.Session

ExitPageGTE applies the GTE predicate on the "exit_page" field.

func ExitPageHasPrefix

func ExitPageHasPrefix(v string) predicate.Session

ExitPageHasPrefix applies the HasPrefix predicate on the "exit_page" field.

func ExitPageHasSuffix

func ExitPageHasSuffix(v string) predicate.Session

ExitPageHasSuffix applies the HasSuffix predicate on the "exit_page" field.

func ExitPageIn

func ExitPageIn(vs ...string) predicate.Session

ExitPageIn applies the In predicate on the "exit_page" field.

func ExitPageIsNil

func ExitPageIsNil() predicate.Session

ExitPageIsNil applies the IsNil predicate on the "exit_page" field.

func ExitPageLT

func ExitPageLT(v string) predicate.Session

ExitPageLT applies the LT predicate on the "exit_page" field.

func ExitPageLTE

func ExitPageLTE(v string) predicate.Session

ExitPageLTE applies the LTE predicate on the "exit_page" field.

func ExitPageNEQ

func ExitPageNEQ(v string) predicate.Session

ExitPageNEQ applies the NEQ predicate on the "exit_page" field.

func ExitPageNotIn

func ExitPageNotIn(vs ...string) predicate.Session

ExitPageNotIn applies the NotIn predicate on the "exit_page" field.

func ExitPageNotNil

func ExitPageNotNil() predicate.Session

ExitPageNotNil applies the NotNil predicate on the "exit_page" field.

func HasJourney

func HasJourney() predicate.Session

HasJourney applies the HasEdge predicate on the "journey" edge.

func HasJourneyWith

func HasJourneyWith(preds ...predicate.Journey) predicate.Session

HasJourneyWith applies the HasEdge predicate on the "journey" edge with a given conditions (other predicates).

func HasProject

func HasProject() predicate.Session

HasProject applies the HasEdge predicate on the "project" edge.

func HasProjectWith

func HasProjectWith(preds ...predicate.Project) predicate.Session

HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Session

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Session

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Session

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Session

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Session

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Session

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Session

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Session

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Session

IDNotIn applies the NotIn predicate on the ID field.

func JourneyID

func JourneyID(v uuid.UUID) predicate.Session

JourneyID applies equality check predicate on the "journey_id" field. It's identical to JourneyIDEQ.

func JourneyIDEQ

func JourneyIDEQ(v uuid.UUID) predicate.Session

JourneyIDEQ applies the EQ predicate on the "journey_id" field.

func JourneyIDIn

func JourneyIDIn(vs ...uuid.UUID) predicate.Session

JourneyIDIn applies the In predicate on the "journey_id" field.

func JourneyIDIsNil

func JourneyIDIsNil() predicate.Session

JourneyIDIsNil applies the IsNil predicate on the "journey_id" field.

func JourneyIDNEQ

func JourneyIDNEQ(v uuid.UUID) predicate.Session

JourneyIDNEQ applies the NEQ predicate on the "journey_id" field.

func JourneyIDNotIn

func JourneyIDNotIn(vs ...uuid.UUID) predicate.Session

JourneyIDNotIn applies the NotIn predicate on the "journey_id" field.

func JourneyIDNotNil

func JourneyIDNotNil() predicate.Session

JourneyIDNotNil applies the NotNil predicate on the "journey_id" field.

func LastJourneyStepID

func LastJourneyStepID(v string) predicate.Session

LastJourneyStepID applies equality check predicate on the "last_journey_step_id" field. It's identical to LastJourneyStepIDEQ.

func LastJourneyStepIDContains

func LastJourneyStepIDContains(v string) predicate.Session

LastJourneyStepIDContains applies the Contains predicate on the "last_journey_step_id" field.

func LastJourneyStepIDContainsFold

func LastJourneyStepIDContainsFold(v string) predicate.Session

LastJourneyStepIDContainsFold applies the ContainsFold predicate on the "last_journey_step_id" field.

func LastJourneyStepIDEQ

func LastJourneyStepIDEQ(v string) predicate.Session

LastJourneyStepIDEQ applies the EQ predicate on the "last_journey_step_id" field.

func LastJourneyStepIDEqualFold

func LastJourneyStepIDEqualFold(v string) predicate.Session

LastJourneyStepIDEqualFold applies the EqualFold predicate on the "last_journey_step_id" field.

func LastJourneyStepIDGT

func LastJourneyStepIDGT(v string) predicate.Session

LastJourneyStepIDGT applies the GT predicate on the "last_journey_step_id" field.

func LastJourneyStepIDGTE

func LastJourneyStepIDGTE(v string) predicate.Session

LastJourneyStepIDGTE applies the GTE predicate on the "last_journey_step_id" field.

func LastJourneyStepIDHasPrefix

func LastJourneyStepIDHasPrefix(v string) predicate.Session

LastJourneyStepIDHasPrefix applies the HasPrefix predicate on the "last_journey_step_id" field.

func LastJourneyStepIDHasSuffix

func LastJourneyStepIDHasSuffix(v string) predicate.Session

LastJourneyStepIDHasSuffix applies the HasSuffix predicate on the "last_journey_step_id" field.

func LastJourneyStepIDIn

func LastJourneyStepIDIn(vs ...string) predicate.Session

LastJourneyStepIDIn applies the In predicate on the "last_journey_step_id" field.

func LastJourneyStepIDIsNil

func LastJourneyStepIDIsNil() predicate.Session

LastJourneyStepIDIsNil applies the IsNil predicate on the "last_journey_step_id" field.

func LastJourneyStepIDLT

func LastJourneyStepIDLT(v string) predicate.Session

LastJourneyStepIDLT applies the LT predicate on the "last_journey_step_id" field.

func LastJourneyStepIDLTE

func LastJourneyStepIDLTE(v string) predicate.Session

LastJourneyStepIDLTE applies the LTE predicate on the "last_journey_step_id" field.

func LastJourneyStepIDNEQ

func LastJourneyStepIDNEQ(v string) predicate.Session

LastJourneyStepIDNEQ applies the NEQ predicate on the "last_journey_step_id" field.

func LastJourneyStepIDNotIn

func LastJourneyStepIDNotIn(vs ...string) predicate.Session

LastJourneyStepIDNotIn applies the NotIn predicate on the "last_journey_step_id" field.

func LastJourneyStepIDNotNil

func LastJourneyStepIDNotNil() predicate.Session

LastJourneyStepIDNotNil applies the NotNil predicate on the "last_journey_step_id" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Session) predicate.Session

Or groups predicates with the OR operator between them.

func OrgID

func OrgID(v uuid.UUID) predicate.Session

OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.

func OrgIDEQ

func OrgIDEQ(v uuid.UUID) predicate.Session

OrgIDEQ applies the EQ predicate on the "org_id" field.

func OrgIDGT

func OrgIDGT(v uuid.UUID) predicate.Session

OrgIDGT applies the GT predicate on the "org_id" field.

func OrgIDGTE

func OrgIDGTE(v uuid.UUID) predicate.Session

OrgIDGTE applies the GTE predicate on the "org_id" field.

func OrgIDIn

func OrgIDIn(vs ...uuid.UUID) predicate.Session

OrgIDIn applies the In predicate on the "org_id" field.

func OrgIDLT

func OrgIDLT(v uuid.UUID) predicate.Session

OrgIDLT applies the LT predicate on the "org_id" field.

func OrgIDLTE

func OrgIDLTE(v uuid.UUID) predicate.Session

OrgIDLTE applies the LTE predicate on the "org_id" field.

func OrgIDNEQ

func OrgIDNEQ(v uuid.UUID) predicate.Session

OrgIDNEQ applies the NEQ predicate on the "org_id" field.

func OrgIDNotIn

func OrgIDNotIn(vs ...uuid.UUID) predicate.Session

OrgIDNotIn applies the NotIn predicate on the "org_id" field.

func Os

func Os(v string) predicate.Session

Os applies equality check predicate on the "os" field. It's identical to OsEQ.

func OsContains

func OsContains(v string) predicate.Session

OsContains applies the Contains predicate on the "os" field.

func OsContainsFold

func OsContainsFold(v string) predicate.Session

OsContainsFold applies the ContainsFold predicate on the "os" field.

func OsEQ

func OsEQ(v string) predicate.Session

OsEQ applies the EQ predicate on the "os" field.

func OsEqualFold

func OsEqualFold(v string) predicate.Session

OsEqualFold applies the EqualFold predicate on the "os" field.

func OsGT

func OsGT(v string) predicate.Session

OsGT applies the GT predicate on the "os" field.

func OsGTE

func OsGTE(v string) predicate.Session

OsGTE applies the GTE predicate on the "os" field.

func OsHasPrefix

func OsHasPrefix(v string) predicate.Session

OsHasPrefix applies the HasPrefix predicate on the "os" field.

func OsHasSuffix

func OsHasSuffix(v string) predicate.Session

OsHasSuffix applies the HasSuffix predicate on the "os" field.

func OsIn

func OsIn(vs ...string) predicate.Session

OsIn applies the In predicate on the "os" field.

func OsIsNil

func OsIsNil() predicate.Session

OsIsNil applies the IsNil predicate on the "os" field.

func OsLT

func OsLT(v string) predicate.Session

OsLT applies the LT predicate on the "os" field.

func OsLTE

func OsLTE(v string) predicate.Session

OsLTE applies the LTE predicate on the "os" field.

func OsNEQ

func OsNEQ(v string) predicate.Session

OsNEQ applies the NEQ predicate on the "os" field.

func OsNotIn

func OsNotIn(vs ...string) predicate.Session

OsNotIn applies the NotIn predicate on the "os" field.

func OsNotNil

func OsNotNil() predicate.Session

OsNotNil applies the NotNil predicate on the "os" field.

func PageCount

func PageCount(v int) predicate.Session

PageCount applies equality check predicate on the "page_count" field. It's identical to PageCountEQ.

func PageCountEQ

func PageCountEQ(v int) predicate.Session

PageCountEQ applies the EQ predicate on the "page_count" field.

func PageCountGT

func PageCountGT(v int) predicate.Session

PageCountGT applies the GT predicate on the "page_count" field.

func PageCountGTE

func PageCountGTE(v int) predicate.Session

PageCountGTE applies the GTE predicate on the "page_count" field.

func PageCountIn

func PageCountIn(vs ...int) predicate.Session

PageCountIn applies the In predicate on the "page_count" field.

func PageCountLT

func PageCountLT(v int) predicate.Session

PageCountLT applies the LT predicate on the "page_count" field.

func PageCountLTE

func PageCountLTE(v int) predicate.Session

PageCountLTE applies the LTE predicate on the "page_count" field.

func PageCountNEQ

func PageCountNEQ(v int) predicate.Session

PageCountNEQ applies the NEQ predicate on the "page_count" field.

func PageCountNotIn

func PageCountNotIn(vs ...int) predicate.Session

PageCountNotIn applies the NotIn predicate on the "page_count" field.

func ProjectID

func ProjectID(v uuid.UUID) predicate.Session

ProjectID applies equality check predicate on the "project_id" field. It's identical to ProjectIDEQ.

func ProjectIDEQ

func ProjectIDEQ(v uuid.UUID) predicate.Session

ProjectIDEQ applies the EQ predicate on the "project_id" field.

func ProjectIDIn

func ProjectIDIn(vs ...uuid.UUID) predicate.Session

ProjectIDIn applies the In predicate on the "project_id" field.

func ProjectIDNEQ

func ProjectIDNEQ(v uuid.UUID) predicate.Session

ProjectIDNEQ applies the NEQ predicate on the "project_id" field.

func ProjectIDNotIn

func ProjectIDNotIn(vs ...uuid.UUID) predicate.Session

ProjectIDNotIn applies the NotIn predicate on the "project_id" field.

func Region

func Region(v string) predicate.Session

Region applies equality check predicate on the "region" field. It's identical to RegionEQ.

func RegionContains

func RegionContains(v string) predicate.Session

RegionContains applies the Contains predicate on the "region" field.

func RegionContainsFold

func RegionContainsFold(v string) predicate.Session

RegionContainsFold applies the ContainsFold predicate on the "region" field.

func RegionEQ

func RegionEQ(v string) predicate.Session

RegionEQ applies the EQ predicate on the "region" field.

func RegionEqualFold

func RegionEqualFold(v string) predicate.Session

RegionEqualFold applies the EqualFold predicate on the "region" field.

func RegionGT

func RegionGT(v string) predicate.Session

RegionGT applies the GT predicate on the "region" field.

func RegionGTE

func RegionGTE(v string) predicate.Session

RegionGTE applies the GTE predicate on the "region" field.

func RegionHasPrefix

func RegionHasPrefix(v string) predicate.Session

RegionHasPrefix applies the HasPrefix predicate on the "region" field.

func RegionHasSuffix

func RegionHasSuffix(v string) predicate.Session

RegionHasSuffix applies the HasSuffix predicate on the "region" field.

func RegionIn

func RegionIn(vs ...string) predicate.Session

RegionIn applies the In predicate on the "region" field.

func RegionIsNil

func RegionIsNil() predicate.Session

RegionIsNil applies the IsNil predicate on the "region" field.

func RegionLT

func RegionLT(v string) predicate.Session

RegionLT applies the LT predicate on the "region" field.

func RegionLTE

func RegionLTE(v string) predicate.Session

RegionLTE applies the LTE predicate on the "region" field.

func RegionNEQ

func RegionNEQ(v string) predicate.Session

RegionNEQ applies the NEQ predicate on the "region" field.

func RegionNotIn

func RegionNotIn(vs ...string) predicate.Session

RegionNotIn applies the NotIn predicate on the "region" field.

func RegionNotNil

func RegionNotNil() predicate.Session

RegionNotNil applies the NotNil predicate on the "region" field.

func SessionID

func SessionID(v string) predicate.Session

SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.

func SessionIDContains

func SessionIDContains(v string) predicate.Session

SessionIDContains applies the Contains predicate on the "session_id" field.

func SessionIDContainsFold

func SessionIDContainsFold(v string) predicate.Session

SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.

func SessionIDEQ

func SessionIDEQ(v string) predicate.Session

SessionIDEQ applies the EQ predicate on the "session_id" field.

func SessionIDEqualFold

func SessionIDEqualFold(v string) predicate.Session

SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.

func SessionIDGT

func SessionIDGT(v string) predicate.Session

SessionIDGT applies the GT predicate on the "session_id" field.

func SessionIDGTE

func SessionIDGTE(v string) predicate.Session

SessionIDGTE applies the GTE predicate on the "session_id" field.

func SessionIDHasPrefix

func SessionIDHasPrefix(v string) predicate.Session

SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.

func SessionIDHasSuffix

func SessionIDHasSuffix(v string) predicate.Session

SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.

func SessionIDIn

func SessionIDIn(vs ...string) predicate.Session

SessionIDIn applies the In predicate on the "session_id" field.

func SessionIDLT

func SessionIDLT(v string) predicate.Session

SessionIDLT applies the LT predicate on the "session_id" field.

func SessionIDLTE

func SessionIDLTE(v string) predicate.Session

SessionIDLTE applies the LTE predicate on the "session_id" field.

func SessionIDNEQ

func SessionIDNEQ(v string) predicate.Session

SessionIDNEQ applies the NEQ predicate on the "session_id" field.

func SessionIDNotIn

func SessionIDNotIn(vs ...string) predicate.Session

SessionIDNotIn applies the NotIn predicate on the "session_id" field.

func StartedAt

func StartedAt(v time.Time) predicate.Session

StartedAt applies equality check predicate on the "started_at" field. It's identical to StartedAtEQ.

func StartedAtEQ

func StartedAtEQ(v time.Time) predicate.Session

StartedAtEQ applies the EQ predicate on the "started_at" field.

func StartedAtGT

func StartedAtGT(v time.Time) predicate.Session

StartedAtGT applies the GT predicate on the "started_at" field.

func StartedAtGTE

func StartedAtGTE(v time.Time) predicate.Session

StartedAtGTE applies the GTE predicate on the "started_at" field.

func StartedAtIn

func StartedAtIn(vs ...time.Time) predicate.Session

StartedAtIn applies the In predicate on the "started_at" field.

func StartedAtLT

func StartedAtLT(v time.Time) predicate.Session

StartedAtLT applies the LT predicate on the "started_at" field.

func StartedAtLTE

func StartedAtLTE(v time.Time) predicate.Session

StartedAtLTE applies the LTE predicate on the "started_at" field.

func StartedAtNEQ

func StartedAtNEQ(v time.Time) predicate.Session

StartedAtNEQ applies the NEQ predicate on the "started_at" field.

func StartedAtNotIn

func StartedAtNotIn(vs ...time.Time) predicate.Session

StartedAtNotIn applies the NotIn predicate on the "started_at" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Session

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Session

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Session

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Session

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Session

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Session

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Session

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Session

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Session

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UserAgent

func UserAgent(v string) predicate.Session

UserAgent applies equality check predicate on the "user_agent" field. It's identical to UserAgentEQ.

func UserAgentContains

func UserAgentContains(v string) predicate.Session

UserAgentContains applies the Contains predicate on the "user_agent" field.

func UserAgentContainsFold

func UserAgentContainsFold(v string) predicate.Session

UserAgentContainsFold applies the ContainsFold predicate on the "user_agent" field.

func UserAgentEQ

func UserAgentEQ(v string) predicate.Session

UserAgentEQ applies the EQ predicate on the "user_agent" field.

func UserAgentEqualFold

func UserAgentEqualFold(v string) predicate.Session

UserAgentEqualFold applies the EqualFold predicate on the "user_agent" field.

func UserAgentGT

func UserAgentGT(v string) predicate.Session

UserAgentGT applies the GT predicate on the "user_agent" field.

func UserAgentGTE

func UserAgentGTE(v string) predicate.Session

UserAgentGTE applies the GTE predicate on the "user_agent" field.

func UserAgentHasPrefix

func UserAgentHasPrefix(v string) predicate.Session

UserAgentHasPrefix applies the HasPrefix predicate on the "user_agent" field.

func UserAgentHasSuffix

func UserAgentHasSuffix(v string) predicate.Session

UserAgentHasSuffix applies the HasSuffix predicate on the "user_agent" field.

func UserAgentIn

func UserAgentIn(vs ...string) predicate.Session

UserAgentIn applies the In predicate on the "user_agent" field.

func UserAgentIsNil

func UserAgentIsNil() predicate.Session

UserAgentIsNil applies the IsNil predicate on the "user_agent" field.

func UserAgentLT

func UserAgentLT(v string) predicate.Session

UserAgentLT applies the LT predicate on the "user_agent" field.

func UserAgentLTE

func UserAgentLTE(v string) predicate.Session

UserAgentLTE applies the LTE predicate on the "user_agent" field.

func UserAgentNEQ

func UserAgentNEQ(v string) predicate.Session

UserAgentNEQ applies the NEQ predicate on the "user_agent" field.

func UserAgentNotIn

func UserAgentNotIn(vs ...string) predicate.Session

UserAgentNotIn applies the NotIn predicate on the "user_agent" field.

func UserAgentNotNil

func UserAgentNotNil() predicate.Session

UserAgentNotNil applies the NotNil predicate on the "user_agent" field.

func UserID

func UserID(v string) predicate.Session

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDContains

func UserIDContains(v string) predicate.Session

UserIDContains applies the Contains predicate on the "user_id" field.

func UserIDContainsFold

func UserIDContainsFold(v string) predicate.Session

UserIDContainsFold applies the ContainsFold predicate on the "user_id" field.

func UserIDEQ

func UserIDEQ(v string) predicate.Session

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDEqualFold

func UserIDEqualFold(v string) predicate.Session

UserIDEqualFold applies the EqualFold predicate on the "user_id" field.

func UserIDGT

func UserIDGT(v string) predicate.Session

UserIDGT applies the GT predicate on the "user_id" field.

func UserIDGTE

func UserIDGTE(v string) predicate.Session

UserIDGTE applies the GTE predicate on the "user_id" field.

func UserIDHasPrefix

func UserIDHasPrefix(v string) predicate.Session

UserIDHasPrefix applies the HasPrefix predicate on the "user_id" field.

func UserIDHasSuffix

func UserIDHasSuffix(v string) predicate.Session

UserIDHasSuffix applies the HasSuffix predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...string) predicate.Session

UserIDIn applies the In predicate on the "user_id" field.

func UserIDIsNil

func UserIDIsNil() predicate.Session

UserIDIsNil applies the IsNil predicate on the "user_id" field.

func UserIDLT

func UserIDLT(v string) predicate.Session

UserIDLT applies the LT predicate on the "user_id" field.

func UserIDLTE

func UserIDLTE(v string) predicate.Session

UserIDLTE applies the LTE predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v string) predicate.Session

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...string) predicate.Session

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func UserIDNotNil

func UserIDNotNil() predicate.Session

UserIDNotNil applies the NotNil predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Session queries.

func ByBrowser

func ByBrowser(opts ...sql.OrderTermOption) OrderOption

ByBrowser orders the results by the browser field.

func ByCity

func ByCity(opts ...sql.OrderTermOption) OrderOption

ByCity orders the results by the city field.

func ByConversionStatus

func ByConversionStatus(opts ...sql.OrderTermOption) OrderOption

ByConversionStatus orders the results by the conversion_status field.

func ByCountry

func ByCountry(opts ...sql.OrderTermOption) OrderOption

ByCountry orders the results by the country field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDeviceType

func ByDeviceType(opts ...sql.OrderTermOption) OrderOption

ByDeviceType orders the results by the device_type field.

func ByDurationMs

func ByDurationMs(opts ...sql.OrderTermOption) OrderOption

ByDurationMs orders the results by the duration_ms field.

func ByEndedAt

func ByEndedAt(opts ...sql.OrderTermOption) OrderOption

ByEndedAt orders the results by the ended_at field.

func ByEntryPage

func ByEntryPage(opts ...sql.OrderTermOption) OrderOption

ByEntryPage orders the results by the entry_page field.

func ByEventCount

func ByEventCount(opts ...sql.OrderTermOption) OrderOption

ByEventCount orders the results by the event_count field.

func ByExitPage

func ByExitPage(opts ...sql.OrderTermOption) OrderOption

ByExitPage orders the results by the exit_page field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByJourneyField

func ByJourneyField(field string, opts ...sql.OrderTermOption) OrderOption

ByJourneyField orders the results by journey field.

func ByJourneyID

func ByJourneyID(opts ...sql.OrderTermOption) OrderOption

ByJourneyID orders the results by the journey_id field.

func ByLastJourneyStepID

func ByLastJourneyStepID(opts ...sql.OrderTermOption) OrderOption

ByLastJourneyStepID orders the results by the last_journey_step_id field.

func ByOrgID

func ByOrgID(opts ...sql.OrderTermOption) OrderOption

ByOrgID orders the results by the org_id field.

func ByOs

func ByOs(opts ...sql.OrderTermOption) OrderOption

ByOs orders the results by the os field.

func ByPageCount

func ByPageCount(opts ...sql.OrderTermOption) OrderOption

ByPageCount orders the results by the page_count field.

func ByProjectField

func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption

ByProjectField orders the results by project field.

func ByProjectID

func ByProjectID(opts ...sql.OrderTermOption) OrderOption

ByProjectID orders the results by the project_id field.

func ByRegion

func ByRegion(opts ...sql.OrderTermOption) OrderOption

ByRegion orders the results by the region field.

func BySessionID

func BySessionID(opts ...sql.OrderTermOption) OrderOption

BySessionID orders the results by the session_id field.

func ByStartedAt

func ByStartedAt(opts ...sql.OrderTermOption) OrderOption

ByStartedAt orders the results by the started_at field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserAgent

func ByUserAgent(opts ...sql.OrderTermOption) OrderOption

ByUserAgent orders the results by the user_agent field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to