Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Journey) predicate.Journey
- func AvgDurationMs(v int64) predicate.Journey
- func AvgDurationMsEQ(v int64) predicate.Journey
- func AvgDurationMsGT(v int64) predicate.Journey
- func AvgDurationMsGTE(v int64) predicate.Journey
- func AvgDurationMsIn(vs ...int64) predicate.Journey
- func AvgDurationMsLT(v int64) predicate.Journey
- func AvgDurationMsLTE(v int64) predicate.Journey
- func AvgDurationMsNEQ(v int64) predicate.Journey
- func AvgDurationMsNotIn(vs ...int64) predicate.Journey
- func ConversionRate(v float64) predicate.Journey
- func ConversionRateEQ(v float64) predicate.Journey
- func ConversionRateGT(v float64) predicate.Journey
- func ConversionRateGTE(v float64) predicate.Journey
- func ConversionRateIn(vs ...float64) predicate.Journey
- func ConversionRateLT(v float64) predicate.Journey
- func ConversionRateLTE(v float64) predicate.Journey
- func ConversionRateNEQ(v float64) predicate.Journey
- func ConversionRateNotIn(vs ...float64) predicate.Journey
- func ConvertedSessions(v int64) predicate.Journey
- func ConvertedSessionsEQ(v int64) predicate.Journey
- func ConvertedSessionsGT(v int64) predicate.Journey
- func ConvertedSessionsGTE(v int64) predicate.Journey
- func ConvertedSessionsIn(vs ...int64) predicate.Journey
- func ConvertedSessionsLT(v int64) predicate.Journey
- func ConvertedSessionsLTE(v int64) predicate.Journey
- func ConvertedSessionsNEQ(v int64) predicate.Journey
- func ConvertedSessionsNotIn(vs ...int64) predicate.Journey
- func CreatedAt(v time.Time) predicate.Journey
- func CreatedAtEQ(v time.Time) predicate.Journey
- func CreatedAtGT(v time.Time) predicate.Journey
- func CreatedAtGTE(v time.Time) predicate.Journey
- func CreatedAtIn(vs ...time.Time) predicate.Journey
- func CreatedAtLT(v time.Time) predicate.Journey
- func CreatedAtLTE(v time.Time) predicate.Journey
- func CreatedAtNEQ(v time.Time) predicate.Journey
- func CreatedAtNotIn(vs ...time.Time) predicate.Journey
- func Description(v string) predicate.Journey
- func DescriptionContains(v string) predicate.Journey
- func DescriptionContainsFold(v string) predicate.Journey
- func DescriptionEQ(v string) predicate.Journey
- func DescriptionEqualFold(v string) predicate.Journey
- func DescriptionGT(v string) predicate.Journey
- func DescriptionGTE(v string) predicate.Journey
- func DescriptionHasPrefix(v string) predicate.Journey
- func DescriptionHasSuffix(v string) predicate.Journey
- func DescriptionIn(vs ...string) predicate.Journey
- func DescriptionIsNil() predicate.Journey
- func DescriptionLT(v string) predicate.Journey
- func DescriptionLTE(v string) predicate.Journey
- func DescriptionNEQ(v string) predicate.Journey
- func DescriptionNotIn(vs ...string) predicate.Journey
- func DescriptionNotNil() predicate.Journey
- func EntryConditionsIsNil() predicate.Journey
- func EntryConditionsNotNil() predicate.Journey
- func ExitConditionsIsNil() predicate.Journey
- func ExitConditionsNotNil() predicate.Journey
- func HasEvents() predicate.Journey
- func HasEventsWith(preds ...predicate.Event) predicate.Journey
- func HasProject() predicate.Journey
- func HasProjectWith(preds ...predicate.Project) predicate.Journey
- func HasSessions() predicate.Journey
- func HasSessionsWith(preds ...predicate.Session) predicate.Journey
- func ID(id uuid.UUID) predicate.Journey
- func IDEQ(id uuid.UUID) predicate.Journey
- func IDGT(id uuid.UUID) predicate.Journey
- func IDGTE(id uuid.UUID) predicate.Journey
- func IDIn(ids ...uuid.UUID) predicate.Journey
- func IDLT(id uuid.UUID) predicate.Journey
- func IDLTE(id uuid.UUID) predicate.Journey
- func IDNEQ(id uuid.UUID) predicate.Journey
- func IDNotIn(ids ...uuid.UUID) predicate.Journey
- func IsActive(v bool) predicate.Journey
- func IsActiveEQ(v bool) predicate.Journey
- func IsActiveNEQ(v bool) predicate.Journey
- func Name(v string) predicate.Journey
- func NameContains(v string) predicate.Journey
- func NameContainsFold(v string) predicate.Journey
- func NameEQ(v string) predicate.Journey
- func NameEqualFold(v string) predicate.Journey
- func NameGT(v string) predicate.Journey
- func NameGTE(v string) predicate.Journey
- func NameHasPrefix(v string) predicate.Journey
- func NameHasSuffix(v string) predicate.Journey
- func NameIn(vs ...string) predicate.Journey
- func NameLT(v string) predicate.Journey
- func NameLTE(v string) predicate.Journey
- func NameNEQ(v string) predicate.Journey
- func NameNotIn(vs ...string) predicate.Journey
- func Not(p predicate.Journey) predicate.Journey
- func Or(predicates ...predicate.Journey) predicate.Journey
- func OrgID(v uuid.UUID) predicate.Journey
- func OrgIDEQ(v uuid.UUID) predicate.Journey
- func OrgIDGT(v uuid.UUID) predicate.Journey
- func OrgIDGTE(v uuid.UUID) predicate.Journey
- func OrgIDIn(vs ...uuid.UUID) predicate.Journey
- func OrgIDLT(v uuid.UUID) predicate.Journey
- func OrgIDLTE(v uuid.UUID) predicate.Journey
- func OrgIDNEQ(v uuid.UUID) predicate.Journey
- func OrgIDNotIn(vs ...uuid.UUID) predicate.Journey
- func ProjectID(v uuid.UUID) predicate.Journey
- func ProjectIDEQ(v uuid.UUID) predicate.Journey
- func ProjectIDIn(vs ...uuid.UUID) predicate.Journey
- func ProjectIDNEQ(v uuid.UUID) predicate.Journey
- func ProjectIDNotIn(vs ...uuid.UUID) predicate.Journey
- func StepsIsNil() predicate.Journey
- func StepsNotNil() predicate.Journey
- func TimeoutMinutes(v int) predicate.Journey
- func TimeoutMinutesEQ(v int) predicate.Journey
- func TimeoutMinutesGT(v int) predicate.Journey
- func TimeoutMinutesGTE(v int) predicate.Journey
- func TimeoutMinutesIn(vs ...int) predicate.Journey
- func TimeoutMinutesLT(v int) predicate.Journey
- func TimeoutMinutesLTE(v int) predicate.Journey
- func TimeoutMinutesNEQ(v int) predicate.Journey
- func TimeoutMinutesNotIn(vs ...int) predicate.Journey
- func TotalSessions(v int64) predicate.Journey
- func TotalSessionsEQ(v int64) predicate.Journey
- func TotalSessionsGT(v int64) predicate.Journey
- func TotalSessionsGTE(v int64) predicate.Journey
- func TotalSessionsIn(vs ...int64) predicate.Journey
- func TotalSessionsLT(v int64) predicate.Journey
- func TotalSessionsLTE(v int64) predicate.Journey
- func TotalSessionsNEQ(v int64) predicate.Journey
- func TotalSessionsNotIn(vs ...int64) predicate.Journey
- func UpdatedAt(v time.Time) predicate.Journey
- func UpdatedAtEQ(v time.Time) predicate.Journey
- func UpdatedAtGT(v time.Time) predicate.Journey
- func UpdatedAtGTE(v time.Time) predicate.Journey
- func UpdatedAtIn(vs ...time.Time) predicate.Journey
- func UpdatedAtLT(v time.Time) predicate.Journey
- func UpdatedAtLTE(v time.Time) predicate.Journey
- func UpdatedAtNEQ(v time.Time) predicate.Journey
- func UpdatedAtNotIn(vs ...time.Time) predicate.Journey
- func ValidColumn(column string) bool
- type OrderOption
- func ByAvgDurationMs(opts ...sql.OrderTermOption) OrderOption
- func ByConversionRate(opts ...sql.OrderTermOption) OrderOption
- func ByConvertedSessions(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIsActive(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOrgID(opts ...sql.OrderTermOption) OrderOption
- func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByProjectID(opts ...sql.OrderTermOption) OrderOption
- func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func BySessionsCount(opts ...sql.OrderTermOption) OrderOption
- func ByTimeoutMinutes(opts ...sql.OrderTermOption) OrderOption
- func ByTotalSessions(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the journey type in the database. Label = "journey" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldOrgID holds the string denoting the org_id field in the database. FieldOrgID = "org_id" // FieldProjectID holds the string denoting the project_id field in the database. FieldProjectID = "project_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldEntryConditions holds the string denoting the entry_conditions field in the database. FieldEntryConditions = "entry_conditions" // FieldExitConditions holds the string denoting the exit_conditions field in the database. FieldExitConditions = "exit_conditions" // FieldSteps holds the string denoting the steps field in the database. FieldSteps = "steps" // FieldTimeoutMinutes holds the string denoting the timeout_minutes field in the database. FieldTimeoutMinutes = "timeout_minutes" // FieldTotalSessions holds the string denoting the total_sessions field in the database. FieldTotalSessions = "total_sessions" // FieldConvertedSessions holds the string denoting the converted_sessions field in the database. FieldConvertedSessions = "converted_sessions" // FieldConversionRate holds the string denoting the conversion_rate field in the database. FieldConversionRate = "conversion_rate" // FieldAvgDurationMs holds the string denoting the avg_duration_ms field in the database. FieldAvgDurationMs = "avg_duration_ms" // FieldIsActive holds the string denoting the is_active field in the database. FieldIsActive = "is_active" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeProject holds the string denoting the project edge name in mutations. EdgeProject = "project" // EdgeEvents holds the string denoting the events edge name in mutations. EdgeEvents = "events" // EdgeSessions holds the string denoting the sessions edge name in mutations. EdgeSessions = "sessions" // Table holds the table name of the journey in the database. Table = "journeys" // ProjectTable is the table that holds the project relation/edge. ProjectTable = "journeys" // ProjectInverseTable is the table name for the Project entity. // It exists in this package in order to avoid circular dependency with the "project" package. ProjectInverseTable = "projects" // ProjectColumn is the table column denoting the project relation/edge. ProjectColumn = "project_id" // EventsTable is the table that holds the events relation/edge. EventsTable = "events" // EventsInverseTable is the table name for the Event entity. // It exists in this package in order to avoid circular dependency with the "event" package. EventsInverseTable = "events" // EventsColumn is the table column denoting the events relation/edge. EventsColumn = "journey_id" // SessionsTable is the table that holds the sessions relation/edge. SessionsTable = "sessions" // SessionsInverseTable is the table name for the Session entity. // It exists in this package in order to avoid circular dependency with the "session" package. SessionsInverseTable = "sessions" // SessionsColumn is the table column denoting the sessions relation/edge. SessionsColumn = "journey_id" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultTimeoutMinutes holds the default value on creation for the "timeout_minutes" field. DefaultTimeoutMinutes int // DefaultTotalSessions holds the default value on creation for the "total_sessions" field. DefaultTotalSessions int64 // DefaultConvertedSessions holds the default value on creation for the "converted_sessions" field. DefaultConvertedSessions int64 // DefaultConversionRate holds the default value on creation for the "conversion_rate" field. DefaultConversionRate float64 // DefaultAvgDurationMs holds the default value on creation for the "avg_duration_ms" field. DefaultAvgDurationMs int64 // DefaultIsActive holds the default value on creation for the "is_active" field. DefaultIsActive bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldOrgID, FieldProjectID, FieldName, FieldDescription, FieldEntryConditions, FieldExitConditions, FieldSteps, FieldTimeoutMinutes, FieldTotalSessions, FieldConvertedSessions, FieldConversionRate, FieldAvgDurationMs, FieldIsActive, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for journey fields.
Functions ¶
func AvgDurationMs ¶
AvgDurationMs applies equality check predicate on the "avg_duration_ms" field. It's identical to AvgDurationMsEQ.
func AvgDurationMsEQ ¶
AvgDurationMsEQ applies the EQ predicate on the "avg_duration_ms" field.
func AvgDurationMsGT ¶
AvgDurationMsGT applies the GT predicate on the "avg_duration_ms" field.
func AvgDurationMsGTE ¶
AvgDurationMsGTE applies the GTE predicate on the "avg_duration_ms" field.
func AvgDurationMsIn ¶
AvgDurationMsIn applies the In predicate on the "avg_duration_ms" field.
func AvgDurationMsLT ¶
AvgDurationMsLT applies the LT predicate on the "avg_duration_ms" field.
func AvgDurationMsLTE ¶
AvgDurationMsLTE applies the LTE predicate on the "avg_duration_ms" field.
func AvgDurationMsNEQ ¶
AvgDurationMsNEQ applies the NEQ predicate on the "avg_duration_ms" field.
func AvgDurationMsNotIn ¶
AvgDurationMsNotIn applies the NotIn predicate on the "avg_duration_ms" field.
func ConversionRate ¶
ConversionRate applies equality check predicate on the "conversion_rate" field. It's identical to ConversionRateEQ.
func ConversionRateEQ ¶
ConversionRateEQ applies the EQ predicate on the "conversion_rate" field.
func ConversionRateGT ¶
ConversionRateGT applies the GT predicate on the "conversion_rate" field.
func ConversionRateGTE ¶
ConversionRateGTE applies the GTE predicate on the "conversion_rate" field.
func ConversionRateIn ¶
ConversionRateIn applies the In predicate on the "conversion_rate" field.
func ConversionRateLT ¶
ConversionRateLT applies the LT predicate on the "conversion_rate" field.
func ConversionRateLTE ¶
ConversionRateLTE applies the LTE predicate on the "conversion_rate" field.
func ConversionRateNEQ ¶
ConversionRateNEQ applies the NEQ predicate on the "conversion_rate" field.
func ConversionRateNotIn ¶
ConversionRateNotIn applies the NotIn predicate on the "conversion_rate" field.
func ConvertedSessions ¶
ConvertedSessions applies equality check predicate on the "converted_sessions" field. It's identical to ConvertedSessionsEQ.
func ConvertedSessionsEQ ¶
ConvertedSessionsEQ applies the EQ predicate on the "converted_sessions" field.
func ConvertedSessionsGT ¶
ConvertedSessionsGT applies the GT predicate on the "converted_sessions" field.
func ConvertedSessionsGTE ¶
ConvertedSessionsGTE applies the GTE predicate on the "converted_sessions" field.
func ConvertedSessionsIn ¶
ConvertedSessionsIn applies the In predicate on the "converted_sessions" field.
func ConvertedSessionsLT ¶
ConvertedSessionsLT applies the LT predicate on the "converted_sessions" field.
func ConvertedSessionsLTE ¶
ConvertedSessionsLTE applies the LTE predicate on the "converted_sessions" field.
func ConvertedSessionsNEQ ¶
ConvertedSessionsNEQ applies the NEQ predicate on the "converted_sessions" field.
func ConvertedSessionsNotIn ¶
ConvertedSessionsNotIn applies the NotIn predicate on the "converted_sessions" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Description ¶
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
DescriptionNotNil applies the NotNil predicate on the "description" field.
func EntryConditionsIsNil ¶
EntryConditionsIsNil applies the IsNil predicate on the "entry_conditions" field.
func EntryConditionsNotNil ¶
EntryConditionsNotNil applies the NotNil predicate on the "entry_conditions" field.
func ExitConditionsIsNil ¶
ExitConditionsIsNil applies the IsNil predicate on the "exit_conditions" field.
func ExitConditionsNotNil ¶
ExitConditionsNotNil applies the NotNil predicate on the "exit_conditions" field.
func HasEventsWith ¶
HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).
func HasProject ¶
HasProject applies the HasEdge predicate on the "project" edge.
func HasProjectWith ¶
HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).
func HasSessions ¶
HasSessions applies the HasEdge predicate on the "sessions" edge.
func HasSessionsWith ¶
HasSessionsWith applies the HasEdge predicate on the "sessions" edge with a given conditions (other predicates).
func IsActive ¶
IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.
func IsActiveEQ ¶
IsActiveEQ applies the EQ predicate on the "is_active" field.
func IsActiveNEQ ¶
IsActiveNEQ applies the NEQ predicate on the "is_active" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func OrgID ¶
OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.
func OrgIDNotIn ¶
OrgIDNotIn applies the NotIn predicate on the "org_id" field.
func ProjectID ¶
ProjectID applies equality check predicate on the "project_id" field. It's identical to ProjectIDEQ.
func ProjectIDEQ ¶
ProjectIDEQ applies the EQ predicate on the "project_id" field.
func ProjectIDIn ¶
ProjectIDIn applies the In predicate on the "project_id" field.
func ProjectIDNEQ ¶
ProjectIDNEQ applies the NEQ predicate on the "project_id" field.
func ProjectIDNotIn ¶
ProjectIDNotIn applies the NotIn predicate on the "project_id" field.
func StepsIsNil ¶
StepsIsNil applies the IsNil predicate on the "steps" field.
func StepsNotNil ¶
StepsNotNil applies the NotNil predicate on the "steps" field.
func TimeoutMinutes ¶
TimeoutMinutes applies equality check predicate on the "timeout_minutes" field. It's identical to TimeoutMinutesEQ.
func TimeoutMinutesEQ ¶
TimeoutMinutesEQ applies the EQ predicate on the "timeout_minutes" field.
func TimeoutMinutesGT ¶
TimeoutMinutesGT applies the GT predicate on the "timeout_minutes" field.
func TimeoutMinutesGTE ¶
TimeoutMinutesGTE applies the GTE predicate on the "timeout_minutes" field.
func TimeoutMinutesIn ¶
TimeoutMinutesIn applies the In predicate on the "timeout_minutes" field.
func TimeoutMinutesLT ¶
TimeoutMinutesLT applies the LT predicate on the "timeout_minutes" field.
func TimeoutMinutesLTE ¶
TimeoutMinutesLTE applies the LTE predicate on the "timeout_minutes" field.
func TimeoutMinutesNEQ ¶
TimeoutMinutesNEQ applies the NEQ predicate on the "timeout_minutes" field.
func TimeoutMinutesNotIn ¶
TimeoutMinutesNotIn applies the NotIn predicate on the "timeout_minutes" field.
func TotalSessions ¶
TotalSessions applies equality check predicate on the "total_sessions" field. It's identical to TotalSessionsEQ.
func TotalSessionsEQ ¶
TotalSessionsEQ applies the EQ predicate on the "total_sessions" field.
func TotalSessionsGT ¶
TotalSessionsGT applies the GT predicate on the "total_sessions" field.
func TotalSessionsGTE ¶
TotalSessionsGTE applies the GTE predicate on the "total_sessions" field.
func TotalSessionsIn ¶
TotalSessionsIn applies the In predicate on the "total_sessions" field.
func TotalSessionsLT ¶
TotalSessionsLT applies the LT predicate on the "total_sessions" field.
func TotalSessionsLTE ¶
TotalSessionsLTE applies the LTE predicate on the "total_sessions" field.
func TotalSessionsNEQ ¶
TotalSessionsNEQ applies the NEQ predicate on the "total_sessions" field.
func TotalSessionsNotIn ¶
TotalSessionsNotIn applies the NotIn predicate on the "total_sessions" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Journey queries.
func ByAvgDurationMs ¶
func ByAvgDurationMs(opts ...sql.OrderTermOption) OrderOption
ByAvgDurationMs orders the results by the avg_duration_ms field.
func ByConversionRate ¶
func ByConversionRate(opts ...sql.OrderTermOption) OrderOption
ByConversionRate orders the results by the conversion_rate field.
func ByConvertedSessions ¶
func ByConvertedSessions(opts ...sql.OrderTermOption) OrderOption
ByConvertedSessions orders the results by the converted_sessions field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByEvents ¶
func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEvents orders the results by events terms.
func ByEventsCount ¶
func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
ByEventsCount orders the results by events count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIsActive ¶
func ByIsActive(opts ...sql.OrderTermOption) OrderOption
ByIsActive orders the results by the is_active field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOrgID ¶
func ByOrgID(opts ...sql.OrderTermOption) OrderOption
ByOrgID orders the results by the org_id field.
func ByProjectField ¶
func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
ByProjectField orders the results by project field.
func ByProjectID ¶
func ByProjectID(opts ...sql.OrderTermOption) OrderOption
ByProjectID orders the results by the project_id field.
func BySessions ¶
func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
BySessions orders the results by sessions terms.
func BySessionsCount ¶
func BySessionsCount(opts ...sql.OrderTermOption) OrderOption
BySessionsCount orders the results by sessions count.
func ByTimeoutMinutes ¶
func ByTimeoutMinutes(opts ...sql.OrderTermOption) OrderOption
ByTimeoutMinutes orders the results by the timeout_minutes field.
func ByTotalSessions ¶
func ByTotalSessions(opts ...sql.OrderTermOption) OrderOption
ByTotalSessions orders the results by the total_sessions field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.