Documentation
¶
Index ¶
- Constants
- Variables
- func APIKey(v string) predicate.Project
- func APIKeyContains(v string) predicate.Project
- func APIKeyContainsFold(v string) predicate.Project
- func APIKeyEQ(v string) predicate.Project
- func APIKeyEqualFold(v string) predicate.Project
- func APIKeyGT(v string) predicate.Project
- func APIKeyGTE(v string) predicate.Project
- func APIKeyHasPrefix(v string) predicate.Project
- func APIKeyHasSuffix(v string) predicate.Project
- func APIKeyIn(vs ...string) predicate.Project
- func APIKeyLT(v string) predicate.Project
- func APIKeyLTE(v string) predicate.Project
- func APIKeyNEQ(v string) predicate.Project
- func APIKeyNotIn(vs ...string) predicate.Project
- func And(predicates ...predicate.Project) predicate.Project
- func CreatedAt(v time.Time) predicate.Project
- func CreatedAtEQ(v time.Time) predicate.Project
- func CreatedAtGT(v time.Time) predicate.Project
- func CreatedAtGTE(v time.Time) predicate.Project
- func CreatedAtIn(vs ...time.Time) predicate.Project
- func CreatedAtLT(v time.Time) predicate.Project
- func CreatedAtLTE(v time.Time) predicate.Project
- func CreatedAtNEQ(v time.Time) predicate.Project
- func CreatedAtNotIn(vs ...time.Time) predicate.Project
- func HasEvents() predicate.Project
- func HasEventsWith(preds ...predicate.Event) predicate.Project
- func HasJourneys() predicate.Project
- func HasJourneysWith(preds ...predicate.Journey) predicate.Project
- func HasOrganization() predicate.Project
- func HasOrganizationWith(preds ...predicate.Organization) predicate.Project
- func HasSessions() predicate.Project
- func HasSessionsWith(preds ...predicate.Session) predicate.Project
- func ID(id uuid.UUID) predicate.Project
- func IDEQ(id uuid.UUID) predicate.Project
- func IDGT(id uuid.UUID) predicate.Project
- func IDGTE(id uuid.UUID) predicate.Project
- func IDIn(ids ...uuid.UUID) predicate.Project
- func IDLT(id uuid.UUID) predicate.Project
- func IDLTE(id uuid.UUID) predicate.Project
- func IDNEQ(id uuid.UUID) predicate.Project
- func IDNotIn(ids ...uuid.UUID) predicate.Project
- func Name(v string) predicate.Project
- func NameContains(v string) predicate.Project
- func NameContainsFold(v string) predicate.Project
- func NameEQ(v string) predicate.Project
- func NameEqualFold(v string) predicate.Project
- func NameGT(v string) predicate.Project
- func NameGTE(v string) predicate.Project
- func NameHasPrefix(v string) predicate.Project
- func NameHasSuffix(v string) predicate.Project
- func NameIn(vs ...string) predicate.Project
- func NameLT(v string) predicate.Project
- func NameLTE(v string) predicate.Project
- func NameNEQ(v string) predicate.Project
- func NameNotIn(vs ...string) predicate.Project
- func Not(p predicate.Project) predicate.Project
- func Or(predicates ...predicate.Project) predicate.Project
- func OrgID(v uuid.UUID) predicate.Project
- func OrgIDEQ(v uuid.UUID) predicate.Project
- func OrgIDIn(vs ...uuid.UUID) predicate.Project
- func OrgIDNEQ(v uuid.UUID) predicate.Project
- func OrgIDNotIn(vs ...uuid.UUID) predicate.Project
- func SettingsIsNil() predicate.Project
- func SettingsNotNil() predicate.Project
- func Slug(v string) predicate.Project
- func SlugContains(v string) predicate.Project
- func SlugContainsFold(v string) predicate.Project
- func SlugEQ(v string) predicate.Project
- func SlugEqualFold(v string) predicate.Project
- func SlugGT(v string) predicate.Project
- func SlugGTE(v string) predicate.Project
- func SlugHasPrefix(v string) predicate.Project
- func SlugHasSuffix(v string) predicate.Project
- func SlugIn(vs ...string) predicate.Project
- func SlugLT(v string) predicate.Project
- func SlugLTE(v string) predicate.Project
- func SlugNEQ(v string) predicate.Project
- func SlugNotIn(vs ...string) predicate.Project
- func UpdatedAt(v time.Time) predicate.Project
- func UpdatedAtEQ(v time.Time) predicate.Project
- func UpdatedAtGT(v time.Time) predicate.Project
- func UpdatedAtGTE(v time.Time) predicate.Project
- func UpdatedAtIn(vs ...time.Time) predicate.Project
- func UpdatedAtLT(v time.Time) predicate.Project
- func UpdatedAtLTE(v time.Time) predicate.Project
- func UpdatedAtNEQ(v time.Time) predicate.Project
- func UpdatedAtNotIn(vs ...time.Time) predicate.Project
- func ValidColumn(column string) bool
- type OrderOption
- func ByAPIKey(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByJourneys(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByJourneysCount(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOrgID(opts ...sql.OrderTermOption) OrderOption
- func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption
- func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func BySessionsCount(opts ...sql.OrderTermOption) OrderOption
- func BySlug(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the project type in the database. Label = "project" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldOrgID holds the string denoting the org_id field in the database. FieldOrgID = "org_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldSlug holds the string denoting the slug field in the database. FieldSlug = "slug" // FieldAPIKey holds the string denoting the api_key field in the database. FieldAPIKey = "api_key" // FieldSettings holds the string denoting the settings field in the database. FieldSettings = "settings" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeOrganization holds the string denoting the organization edge name in mutations. EdgeOrganization = "organization" // EdgeEvents holds the string denoting the events edge name in mutations. EdgeEvents = "events" // EdgeSessions holds the string denoting the sessions edge name in mutations. EdgeSessions = "sessions" // EdgeJourneys holds the string denoting the journeys edge name in mutations. EdgeJourneys = "journeys" // Table holds the table name of the project in the database. Table = "projects" // OrganizationTable is the table that holds the organization relation/edge. OrganizationTable = "projects" // OrganizationInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OrganizationInverseTable = "organizations" // OrganizationColumn is the table column denoting the organization relation/edge. OrganizationColumn = "org_id" // EventsTable is the table that holds the events relation/edge. EventsTable = "events" // EventsInverseTable is the table name for the Event entity. // It exists in this package in order to avoid circular dependency with the "event" package. EventsInverseTable = "events" // EventsColumn is the table column denoting the events relation/edge. EventsColumn = "project_id" // SessionsTable is the table that holds the sessions relation/edge. SessionsTable = "sessions" // SessionsInverseTable is the table name for the Session entity. // It exists in this package in order to avoid circular dependency with the "session" package. SessionsInverseTable = "sessions" // SessionsColumn is the table column denoting the sessions relation/edge. SessionsColumn = "project_id" // JourneysTable is the table that holds the journeys relation/edge. JourneysTable = "journeys" // JourneysInverseTable is the table name for the Journey entity. // It exists in this package in order to avoid circular dependency with the "journey" package. JourneysInverseTable = "journeys" // JourneysColumn is the table column denoting the journeys relation/edge. JourneysColumn = "project_id" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // SlugValidator is a validator for the "slug" field. It is called by the builders before save. SlugValidator func(string) error // APIKeyValidator is a validator for the "api_key" field. It is called by the builders before save. APIKeyValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldOrgID, FieldName, FieldSlug, FieldAPIKey, FieldSettings, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for project fields.
Functions ¶
func APIKey ¶
APIKey applies equality check predicate on the "api_key" field. It's identical to APIKeyEQ.
func APIKeyContains ¶
APIKeyContains applies the Contains predicate on the "api_key" field.
func APIKeyContainsFold ¶
APIKeyContainsFold applies the ContainsFold predicate on the "api_key" field.
func APIKeyEqualFold ¶
APIKeyEqualFold applies the EqualFold predicate on the "api_key" field.
func APIKeyHasPrefix ¶
APIKeyHasPrefix applies the HasPrefix predicate on the "api_key" field.
func APIKeyHasSuffix ¶
APIKeyHasSuffix applies the HasSuffix predicate on the "api_key" field.
func APIKeyNotIn ¶
APIKeyNotIn applies the NotIn predicate on the "api_key" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasEventsWith ¶
HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).
func HasJourneys ¶
HasJourneys applies the HasEdge predicate on the "journeys" edge.
func HasJourneysWith ¶
HasJourneysWith applies the HasEdge predicate on the "journeys" edge with a given conditions (other predicates).
func HasOrganization ¶
HasOrganization applies the HasEdge predicate on the "organization" edge.
func HasOrganizationWith ¶
func HasOrganizationWith(preds ...predicate.Organization) predicate.Project
HasOrganizationWith applies the HasEdge predicate on the "organization" edge with a given conditions (other predicates).
func HasSessions ¶
HasSessions applies the HasEdge predicate on the "sessions" edge.
func HasSessionsWith ¶
HasSessionsWith applies the HasEdge predicate on the "sessions" edge with a given conditions (other predicates).
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func OrgID ¶
OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.
func OrgIDNotIn ¶
OrgIDNotIn applies the NotIn predicate on the "org_id" field.
func SettingsIsNil ¶
SettingsIsNil applies the IsNil predicate on the "settings" field.
func SettingsNotNil ¶
SettingsNotNil applies the NotNil predicate on the "settings" field.
func SlugContains ¶
SlugContains applies the Contains predicate on the "slug" field.
func SlugContainsFold ¶
SlugContainsFold applies the ContainsFold predicate on the "slug" field.
func SlugEqualFold ¶
SlugEqualFold applies the EqualFold predicate on the "slug" field.
func SlugHasPrefix ¶
SlugHasPrefix applies the HasPrefix predicate on the "slug" field.
func SlugHasSuffix ¶
SlugHasSuffix applies the HasSuffix predicate on the "slug" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Project queries.
func ByAPIKey ¶
func ByAPIKey(opts ...sql.OrderTermOption) OrderOption
ByAPIKey orders the results by the api_key field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByEvents ¶
func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEvents orders the results by events terms.
func ByEventsCount ¶
func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
ByEventsCount orders the results by events count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByJourneys ¶
func ByJourneys(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByJourneys orders the results by journeys terms.
func ByJourneysCount ¶
func ByJourneysCount(opts ...sql.OrderTermOption) OrderOption
ByJourneysCount orders the results by journeys count.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOrgID ¶
func ByOrgID(opts ...sql.OrderTermOption) OrderOption
ByOrgID orders the results by the org_id field.
func ByOrganizationField ¶
func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption
ByOrganizationField orders the results by organization field.
func BySessions ¶
func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
BySessions orders the results by sessions terms.
func BySessionsCount ¶
func BySessionsCount(opts ...sql.OrderTermOption) OrderOption
BySessionsCount orders the results by sessions count.
func BySlug ¶
func BySlug(opts ...sql.OrderTermOption) OrderOption
BySlug orders the results by the slug field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.