Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Session) predicate.Session
- func Browser(v string) predicate.Session
- func BrowserContains(v string) predicate.Session
- func BrowserContainsFold(v string) predicate.Session
- func BrowserEQ(v string) predicate.Session
- func BrowserEqualFold(v string) predicate.Session
- func BrowserGT(v string) predicate.Session
- func BrowserGTE(v string) predicate.Session
- func BrowserHasPrefix(v string) predicate.Session
- func BrowserHasSuffix(v string) predicate.Session
- func BrowserIn(vs ...string) predicate.Session
- func BrowserIsNil() predicate.Session
- func BrowserLT(v string) predicate.Session
- func BrowserLTE(v string) predicate.Session
- func BrowserNEQ(v string) predicate.Session
- func BrowserNotIn(vs ...string) predicate.Session
- func BrowserNotNil() predicate.Session
- func City(v string) predicate.Session
- func CityContains(v string) predicate.Session
- func CityContainsFold(v string) predicate.Session
- func CityEQ(v string) predicate.Session
- func CityEqualFold(v string) predicate.Session
- func CityGT(v string) predicate.Session
- func CityGTE(v string) predicate.Session
- func CityHasPrefix(v string) predicate.Session
- func CityHasSuffix(v string) predicate.Session
- func CityIn(vs ...string) predicate.Session
- func CityIsNil() predicate.Session
- func CityLT(v string) predicate.Session
- func CityLTE(v string) predicate.Session
- func CityNEQ(v string) predicate.Session
- func CityNotIn(vs ...string) predicate.Session
- func CityNotNil() predicate.Session
- func ConversionStatus(v string) predicate.Session
- func ConversionStatusContains(v string) predicate.Session
- func ConversionStatusContainsFold(v string) predicate.Session
- func ConversionStatusEQ(v string) predicate.Session
- func ConversionStatusEqualFold(v string) predicate.Session
- func ConversionStatusGT(v string) predicate.Session
- func ConversionStatusGTE(v string) predicate.Session
- func ConversionStatusHasPrefix(v string) predicate.Session
- func ConversionStatusHasSuffix(v string) predicate.Session
- func ConversionStatusIn(vs ...string) predicate.Session
- func ConversionStatusIsNil() predicate.Session
- func ConversionStatusLT(v string) predicate.Session
- func ConversionStatusLTE(v string) predicate.Session
- func ConversionStatusNEQ(v string) predicate.Session
- func ConversionStatusNotIn(vs ...string) predicate.Session
- func ConversionStatusNotNil() predicate.Session
- func Country(v string) predicate.Session
- func CountryContains(v string) predicate.Session
- func CountryContainsFold(v string) predicate.Session
- func CountryEQ(v string) predicate.Session
- func CountryEqualFold(v string) predicate.Session
- func CountryGT(v string) predicate.Session
- func CountryGTE(v string) predicate.Session
- func CountryHasPrefix(v string) predicate.Session
- func CountryHasSuffix(v string) predicate.Session
- func CountryIn(vs ...string) predicate.Session
- func CountryIsNil() predicate.Session
- func CountryLT(v string) predicate.Session
- func CountryLTE(v string) predicate.Session
- func CountryNEQ(v string) predicate.Session
- func CountryNotIn(vs ...string) predicate.Session
- func CountryNotNil() predicate.Session
- func CreatedAt(v time.Time) predicate.Session
- func CreatedAtEQ(v time.Time) predicate.Session
- func CreatedAtGT(v time.Time) predicate.Session
- func CreatedAtGTE(v time.Time) predicate.Session
- func CreatedAtIn(vs ...time.Time) predicate.Session
- func CreatedAtLT(v time.Time) predicate.Session
- func CreatedAtLTE(v time.Time) predicate.Session
- func CreatedAtNEQ(v time.Time) predicate.Session
- func CreatedAtNotIn(vs ...time.Time) predicate.Session
- func DeviceType(v string) predicate.Session
- func DeviceTypeContains(v string) predicate.Session
- func DeviceTypeContainsFold(v string) predicate.Session
- func DeviceTypeEQ(v string) predicate.Session
- func DeviceTypeEqualFold(v string) predicate.Session
- func DeviceTypeGT(v string) predicate.Session
- func DeviceTypeGTE(v string) predicate.Session
- func DeviceTypeHasPrefix(v string) predicate.Session
- func DeviceTypeHasSuffix(v string) predicate.Session
- func DeviceTypeIn(vs ...string) predicate.Session
- func DeviceTypeIsNil() predicate.Session
- func DeviceTypeLT(v string) predicate.Session
- func DeviceTypeLTE(v string) predicate.Session
- func DeviceTypeNEQ(v string) predicate.Session
- func DeviceTypeNotIn(vs ...string) predicate.Session
- func DeviceTypeNotNil() predicate.Session
- func DurationMs(v int64) predicate.Session
- func DurationMsEQ(v int64) predicate.Session
- func DurationMsGT(v int64) predicate.Session
- func DurationMsGTE(v int64) predicate.Session
- func DurationMsIn(vs ...int64) predicate.Session
- func DurationMsLT(v int64) predicate.Session
- func DurationMsLTE(v int64) predicate.Session
- func DurationMsNEQ(v int64) predicate.Session
- func DurationMsNotIn(vs ...int64) predicate.Session
- func EndedAt(v time.Time) predicate.Session
- func EndedAtEQ(v time.Time) predicate.Session
- func EndedAtGT(v time.Time) predicate.Session
- func EndedAtGTE(v time.Time) predicate.Session
- func EndedAtIn(vs ...time.Time) predicate.Session
- func EndedAtIsNil() predicate.Session
- func EndedAtLT(v time.Time) predicate.Session
- func EndedAtLTE(v time.Time) predicate.Session
- func EndedAtNEQ(v time.Time) predicate.Session
- func EndedAtNotIn(vs ...time.Time) predicate.Session
- func EndedAtNotNil() predicate.Session
- func EntryPage(v string) predicate.Session
- func EntryPageContains(v string) predicate.Session
- func EntryPageContainsFold(v string) predicate.Session
- func EntryPageEQ(v string) predicate.Session
- func EntryPageEqualFold(v string) predicate.Session
- func EntryPageGT(v string) predicate.Session
- func EntryPageGTE(v string) predicate.Session
- func EntryPageHasPrefix(v string) predicate.Session
- func EntryPageHasSuffix(v string) predicate.Session
- func EntryPageIn(vs ...string) predicate.Session
- func EntryPageIsNil() predicate.Session
- func EntryPageLT(v string) predicate.Session
- func EntryPageLTE(v string) predicate.Session
- func EntryPageNEQ(v string) predicate.Session
- func EntryPageNotIn(vs ...string) predicate.Session
- func EntryPageNotNil() predicate.Session
- func EventCount(v int) predicate.Session
- func EventCountEQ(v int) predicate.Session
- func EventCountGT(v int) predicate.Session
- func EventCountGTE(v int) predicate.Session
- func EventCountIn(vs ...int) predicate.Session
- func EventCountLT(v int) predicate.Session
- func EventCountLTE(v int) predicate.Session
- func EventCountNEQ(v int) predicate.Session
- func EventCountNotIn(vs ...int) predicate.Session
- func ExitPage(v string) predicate.Session
- func ExitPageContains(v string) predicate.Session
- func ExitPageContainsFold(v string) predicate.Session
- func ExitPageEQ(v string) predicate.Session
- func ExitPageEqualFold(v string) predicate.Session
- func ExitPageGT(v string) predicate.Session
- func ExitPageGTE(v string) predicate.Session
- func ExitPageHasPrefix(v string) predicate.Session
- func ExitPageHasSuffix(v string) predicate.Session
- func ExitPageIn(vs ...string) predicate.Session
- func ExitPageIsNil() predicate.Session
- func ExitPageLT(v string) predicate.Session
- func ExitPageLTE(v string) predicate.Session
- func ExitPageNEQ(v string) predicate.Session
- func ExitPageNotIn(vs ...string) predicate.Session
- func ExitPageNotNil() predicate.Session
- func HasJourney() predicate.Session
- func HasJourneyWith(preds ...predicate.Journey) predicate.Session
- func HasProject() predicate.Session
- func HasProjectWith(preds ...predicate.Project) predicate.Session
- func ID(id uuid.UUID) predicate.Session
- func IDEQ(id uuid.UUID) predicate.Session
- func IDGT(id uuid.UUID) predicate.Session
- func IDGTE(id uuid.UUID) predicate.Session
- func IDIn(ids ...uuid.UUID) predicate.Session
- func IDLT(id uuid.UUID) predicate.Session
- func IDLTE(id uuid.UUID) predicate.Session
- func IDNEQ(id uuid.UUID) predicate.Session
- func IDNotIn(ids ...uuid.UUID) predicate.Session
- func JourneyID(v uuid.UUID) predicate.Session
- func JourneyIDEQ(v uuid.UUID) predicate.Session
- func JourneyIDIn(vs ...uuid.UUID) predicate.Session
- func JourneyIDIsNil() predicate.Session
- func JourneyIDNEQ(v uuid.UUID) predicate.Session
- func JourneyIDNotIn(vs ...uuid.UUID) predicate.Session
- func JourneyIDNotNil() predicate.Session
- func LastJourneyStepID(v string) predicate.Session
- func LastJourneyStepIDContains(v string) predicate.Session
- func LastJourneyStepIDContainsFold(v string) predicate.Session
- func LastJourneyStepIDEQ(v string) predicate.Session
- func LastJourneyStepIDEqualFold(v string) predicate.Session
- func LastJourneyStepIDGT(v string) predicate.Session
- func LastJourneyStepIDGTE(v string) predicate.Session
- func LastJourneyStepIDHasPrefix(v string) predicate.Session
- func LastJourneyStepIDHasSuffix(v string) predicate.Session
- func LastJourneyStepIDIn(vs ...string) predicate.Session
- func LastJourneyStepIDIsNil() predicate.Session
- func LastJourneyStepIDLT(v string) predicate.Session
- func LastJourneyStepIDLTE(v string) predicate.Session
- func LastJourneyStepIDNEQ(v string) predicate.Session
- func LastJourneyStepIDNotIn(vs ...string) predicate.Session
- func LastJourneyStepIDNotNil() predicate.Session
- func Not(p predicate.Session) predicate.Session
- func Or(predicates ...predicate.Session) predicate.Session
- func OrgID(v uuid.UUID) predicate.Session
- func OrgIDEQ(v uuid.UUID) predicate.Session
- func OrgIDGT(v uuid.UUID) predicate.Session
- func OrgIDGTE(v uuid.UUID) predicate.Session
- func OrgIDIn(vs ...uuid.UUID) predicate.Session
- func OrgIDLT(v uuid.UUID) predicate.Session
- func OrgIDLTE(v uuid.UUID) predicate.Session
- func OrgIDNEQ(v uuid.UUID) predicate.Session
- func OrgIDNotIn(vs ...uuid.UUID) predicate.Session
- func Os(v string) predicate.Session
- func OsContains(v string) predicate.Session
- func OsContainsFold(v string) predicate.Session
- func OsEQ(v string) predicate.Session
- func OsEqualFold(v string) predicate.Session
- func OsGT(v string) predicate.Session
- func OsGTE(v string) predicate.Session
- func OsHasPrefix(v string) predicate.Session
- func OsHasSuffix(v string) predicate.Session
- func OsIn(vs ...string) predicate.Session
- func OsIsNil() predicate.Session
- func OsLT(v string) predicate.Session
- func OsLTE(v string) predicate.Session
- func OsNEQ(v string) predicate.Session
- func OsNotIn(vs ...string) predicate.Session
- func OsNotNil() predicate.Session
- func PageCount(v int) predicate.Session
- func PageCountEQ(v int) predicate.Session
- func PageCountGT(v int) predicate.Session
- func PageCountGTE(v int) predicate.Session
- func PageCountIn(vs ...int) predicate.Session
- func PageCountLT(v int) predicate.Session
- func PageCountLTE(v int) predicate.Session
- func PageCountNEQ(v int) predicate.Session
- func PageCountNotIn(vs ...int) predicate.Session
- func ProjectID(v uuid.UUID) predicate.Session
- func ProjectIDEQ(v uuid.UUID) predicate.Session
- func ProjectIDIn(vs ...uuid.UUID) predicate.Session
- func ProjectIDNEQ(v uuid.UUID) predicate.Session
- func ProjectIDNotIn(vs ...uuid.UUID) predicate.Session
- func Region(v string) predicate.Session
- func RegionContains(v string) predicate.Session
- func RegionContainsFold(v string) predicate.Session
- func RegionEQ(v string) predicate.Session
- func RegionEqualFold(v string) predicate.Session
- func RegionGT(v string) predicate.Session
- func RegionGTE(v string) predicate.Session
- func RegionHasPrefix(v string) predicate.Session
- func RegionHasSuffix(v string) predicate.Session
- func RegionIn(vs ...string) predicate.Session
- func RegionIsNil() predicate.Session
- func RegionLT(v string) predicate.Session
- func RegionLTE(v string) predicate.Session
- func RegionNEQ(v string) predicate.Session
- func RegionNotIn(vs ...string) predicate.Session
- func RegionNotNil() predicate.Session
- func SessionID(v string) predicate.Session
- func SessionIDContains(v string) predicate.Session
- func SessionIDContainsFold(v string) predicate.Session
- func SessionIDEQ(v string) predicate.Session
- func SessionIDEqualFold(v string) predicate.Session
- func SessionIDGT(v string) predicate.Session
- func SessionIDGTE(v string) predicate.Session
- func SessionIDHasPrefix(v string) predicate.Session
- func SessionIDHasSuffix(v string) predicate.Session
- func SessionIDIn(vs ...string) predicate.Session
- func SessionIDLT(v string) predicate.Session
- func SessionIDLTE(v string) predicate.Session
- func SessionIDNEQ(v string) predicate.Session
- func SessionIDNotIn(vs ...string) predicate.Session
- func StartedAt(v time.Time) predicate.Session
- func StartedAtEQ(v time.Time) predicate.Session
- func StartedAtGT(v time.Time) predicate.Session
- func StartedAtGTE(v time.Time) predicate.Session
- func StartedAtIn(vs ...time.Time) predicate.Session
- func StartedAtLT(v time.Time) predicate.Session
- func StartedAtLTE(v time.Time) predicate.Session
- func StartedAtNEQ(v time.Time) predicate.Session
- func StartedAtNotIn(vs ...time.Time) predicate.Session
- func UpdatedAt(v time.Time) predicate.Session
- func UpdatedAtEQ(v time.Time) predicate.Session
- func UpdatedAtGT(v time.Time) predicate.Session
- func UpdatedAtGTE(v time.Time) predicate.Session
- func UpdatedAtIn(vs ...time.Time) predicate.Session
- func UpdatedAtLT(v time.Time) predicate.Session
- func UpdatedAtLTE(v time.Time) predicate.Session
- func UpdatedAtNEQ(v time.Time) predicate.Session
- func UpdatedAtNotIn(vs ...time.Time) predicate.Session
- func UserAgent(v string) predicate.Session
- func UserAgentContains(v string) predicate.Session
- func UserAgentContainsFold(v string) predicate.Session
- func UserAgentEQ(v string) predicate.Session
- func UserAgentEqualFold(v string) predicate.Session
- func UserAgentGT(v string) predicate.Session
- func UserAgentGTE(v string) predicate.Session
- func UserAgentHasPrefix(v string) predicate.Session
- func UserAgentHasSuffix(v string) predicate.Session
- func UserAgentIn(vs ...string) predicate.Session
- func UserAgentIsNil() predicate.Session
- func UserAgentLT(v string) predicate.Session
- func UserAgentLTE(v string) predicate.Session
- func UserAgentNEQ(v string) predicate.Session
- func UserAgentNotIn(vs ...string) predicate.Session
- func UserAgentNotNil() predicate.Session
- func UserID(v string) predicate.Session
- func UserIDContains(v string) predicate.Session
- func UserIDContainsFold(v string) predicate.Session
- func UserIDEQ(v string) predicate.Session
- func UserIDEqualFold(v string) predicate.Session
- func UserIDGT(v string) predicate.Session
- func UserIDGTE(v string) predicate.Session
- func UserIDHasPrefix(v string) predicate.Session
- func UserIDHasSuffix(v string) predicate.Session
- func UserIDIn(vs ...string) predicate.Session
- func UserIDIsNil() predicate.Session
- func UserIDLT(v string) predicate.Session
- func UserIDLTE(v string) predicate.Session
- func UserIDNEQ(v string) predicate.Session
- func UserIDNotIn(vs ...string) predicate.Session
- func UserIDNotNil() predicate.Session
- func ValidColumn(column string) bool
- type OrderOption
- func ByBrowser(opts ...sql.OrderTermOption) OrderOption
- func ByCity(opts ...sql.OrderTermOption) OrderOption
- func ByConversionStatus(opts ...sql.OrderTermOption) OrderOption
- func ByCountry(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeviceType(opts ...sql.OrderTermOption) OrderOption
- func ByDurationMs(opts ...sql.OrderTermOption) OrderOption
- func ByEndedAt(opts ...sql.OrderTermOption) OrderOption
- func ByEntryPage(opts ...sql.OrderTermOption) OrderOption
- func ByEventCount(opts ...sql.OrderTermOption) OrderOption
- func ByExitPage(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByJourneyField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByJourneyID(opts ...sql.OrderTermOption) OrderOption
- func ByLastJourneyStepID(opts ...sql.OrderTermOption) OrderOption
- func ByOrgID(opts ...sql.OrderTermOption) OrderOption
- func ByOs(opts ...sql.OrderTermOption) OrderOption
- func ByPageCount(opts ...sql.OrderTermOption) OrderOption
- func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByProjectID(opts ...sql.OrderTermOption) OrderOption
- func ByRegion(opts ...sql.OrderTermOption) OrderOption
- func BySessionID(opts ...sql.OrderTermOption) OrderOption
- func ByStartedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUserAgent(opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the session type in the database. Label = "session" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldOrgID holds the string denoting the org_id field in the database. FieldOrgID = "org_id" // FieldProjectID holds the string denoting the project_id field in the database. FieldProjectID = "project_id" // FieldSessionID holds the string denoting the session_id field in the database. FieldSessionID = "session_id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldStartedAt holds the string denoting the started_at field in the database. FieldStartedAt = "started_at" // FieldEndedAt holds the string denoting the ended_at field in the database. FieldEndedAt = "ended_at" // FieldDurationMs holds the string denoting the duration_ms field in the database. FieldDurationMs = "duration_ms" // FieldEntryPage holds the string denoting the entry_page field in the database. FieldEntryPage = "entry_page" // FieldExitPage holds the string denoting the exit_page field in the database. FieldExitPage = "exit_page" // FieldPageCount holds the string denoting the page_count field in the database. FieldPageCount = "page_count" // FieldEventCount holds the string denoting the event_count field in the database. FieldEventCount = "event_count" // FieldJourneyID holds the string denoting the journey_id field in the database. FieldJourneyID = "journey_id" // FieldLastJourneyStepID holds the string denoting the last_journey_step_id field in the database. FieldLastJourneyStepID = "last_journey_step_id" // FieldConversionStatus holds the string denoting the conversion_status field in the database. FieldConversionStatus = "conversion_status" // FieldUserAgent holds the string denoting the user_agent field in the database. FieldUserAgent = "user_agent" // FieldDeviceType holds the string denoting the device_type field in the database. FieldDeviceType = "device_type" // FieldBrowser holds the string denoting the browser field in the database. FieldBrowser = "browser" // FieldOs holds the string denoting the os field in the database. FieldOs = "os" // FieldCountry holds the string denoting the country field in the database. FieldCountry = "country" // FieldRegion holds the string denoting the region field in the database. FieldRegion = "region" // FieldCity holds the string denoting the city field in the database. FieldCity = "city" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeProject holds the string denoting the project edge name in mutations. EdgeProject = "project" // EdgeJourney holds the string denoting the journey edge name in mutations. EdgeJourney = "journey" // Table holds the table name of the session in the database. Table = "sessions" // ProjectTable is the table that holds the project relation/edge. ProjectTable = "sessions" // ProjectInverseTable is the table name for the Project entity. // It exists in this package in order to avoid circular dependency with the "project" package. ProjectInverseTable = "projects" // ProjectColumn is the table column denoting the project relation/edge. ProjectColumn = "project_id" // JourneyTable is the table that holds the journey relation/edge. JourneyTable = "sessions" // JourneyInverseTable is the table name for the Journey entity. // It exists in this package in order to avoid circular dependency with the "journey" package. JourneyInverseTable = "journeys" // JourneyColumn is the table column denoting the journey relation/edge. JourneyColumn = "journey_id" )
Variables ¶
var ( // SessionIDValidator is a validator for the "session_id" field. It is called by the builders before save. SessionIDValidator func(string) error // UserIDValidator is a validator for the "user_id" field. It is called by the builders before save. UserIDValidator func(string) error // DefaultDurationMs holds the default value on creation for the "duration_ms" field. DefaultDurationMs int64 // EntryPageValidator is a validator for the "entry_page" field. It is called by the builders before save. EntryPageValidator func(string) error // ExitPageValidator is a validator for the "exit_page" field. It is called by the builders before save. ExitPageValidator func(string) error // DefaultPageCount holds the default value on creation for the "page_count" field. DefaultPageCount int // DefaultEventCount holds the default value on creation for the "event_count" field. DefaultEventCount int // LastJourneyStepIDValidator is a validator for the "last_journey_step_id" field. It is called by the builders before save. LastJourneyStepIDValidator func(string) error // ConversionStatusValidator is a validator for the "conversion_status" field. It is called by the builders before save. ConversionStatusValidator func(string) error // UserAgentValidator is a validator for the "user_agent" field. It is called by the builders before save. UserAgentValidator func(string) error // DeviceTypeValidator is a validator for the "device_type" field. It is called by the builders before save. DeviceTypeValidator func(string) error // BrowserValidator is a validator for the "browser" field. It is called by the builders before save. BrowserValidator func(string) error // OsValidator is a validator for the "os" field. It is called by the builders before save. OsValidator func(string) error // CountryValidator is a validator for the "country" field. It is called by the builders before save. CountryValidator func(string) error // RegionValidator is a validator for the "region" field. It is called by the builders before save. RegionValidator func(string) error // CityValidator is a validator for the "city" field. It is called by the builders before save. CityValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldOrgID, FieldProjectID, FieldSessionID, FieldUserID, FieldStartedAt, FieldEndedAt, FieldDurationMs, FieldEntryPage, FieldExitPage, FieldPageCount, FieldEventCount, FieldJourneyID, FieldLastJourneyStepID, FieldConversionStatus, FieldUserAgent, FieldDeviceType, FieldBrowser, FieldOs, FieldCountry, FieldRegion, FieldCity, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for session fields.
Functions ¶
func Browser ¶
Browser applies equality check predicate on the "browser" field. It's identical to BrowserEQ.
func BrowserContains ¶
BrowserContains applies the Contains predicate on the "browser" field.
func BrowserContainsFold ¶
BrowserContainsFold applies the ContainsFold predicate on the "browser" field.
func BrowserEqualFold ¶
BrowserEqualFold applies the EqualFold predicate on the "browser" field.
func BrowserGTE ¶
BrowserGTE applies the GTE predicate on the "browser" field.
func BrowserHasPrefix ¶
BrowserHasPrefix applies the HasPrefix predicate on the "browser" field.
func BrowserHasSuffix ¶
BrowserHasSuffix applies the HasSuffix predicate on the "browser" field.
func BrowserIsNil ¶
BrowserIsNil applies the IsNil predicate on the "browser" field.
func BrowserLTE ¶
BrowserLTE applies the LTE predicate on the "browser" field.
func BrowserNEQ ¶
BrowserNEQ applies the NEQ predicate on the "browser" field.
func BrowserNotIn ¶
BrowserNotIn applies the NotIn predicate on the "browser" field.
func BrowserNotNil ¶
BrowserNotNil applies the NotNil predicate on the "browser" field.
func CityContains ¶
CityContains applies the Contains predicate on the "city" field.
func CityContainsFold ¶
CityContainsFold applies the ContainsFold predicate on the "city" field.
func CityEqualFold ¶
CityEqualFold applies the EqualFold predicate on the "city" field.
func CityHasPrefix ¶
CityHasPrefix applies the HasPrefix predicate on the "city" field.
func CityHasSuffix ¶
CityHasSuffix applies the HasSuffix predicate on the "city" field.
func CityNotNil ¶
CityNotNil applies the NotNil predicate on the "city" field.
func ConversionStatus ¶
ConversionStatus applies equality check predicate on the "conversion_status" field. It's identical to ConversionStatusEQ.
func ConversionStatusContains ¶
ConversionStatusContains applies the Contains predicate on the "conversion_status" field.
func ConversionStatusContainsFold ¶
ConversionStatusContainsFold applies the ContainsFold predicate on the "conversion_status" field.
func ConversionStatusEQ ¶
ConversionStatusEQ applies the EQ predicate on the "conversion_status" field.
func ConversionStatusEqualFold ¶
ConversionStatusEqualFold applies the EqualFold predicate on the "conversion_status" field.
func ConversionStatusGT ¶
ConversionStatusGT applies the GT predicate on the "conversion_status" field.
func ConversionStatusGTE ¶
ConversionStatusGTE applies the GTE predicate on the "conversion_status" field.
func ConversionStatusHasPrefix ¶
ConversionStatusHasPrefix applies the HasPrefix predicate on the "conversion_status" field.
func ConversionStatusHasSuffix ¶
ConversionStatusHasSuffix applies the HasSuffix predicate on the "conversion_status" field.
func ConversionStatusIn ¶
ConversionStatusIn applies the In predicate on the "conversion_status" field.
func ConversionStatusIsNil ¶
ConversionStatusIsNil applies the IsNil predicate on the "conversion_status" field.
func ConversionStatusLT ¶
ConversionStatusLT applies the LT predicate on the "conversion_status" field.
func ConversionStatusLTE ¶
ConversionStatusLTE applies the LTE predicate on the "conversion_status" field.
func ConversionStatusNEQ ¶
ConversionStatusNEQ applies the NEQ predicate on the "conversion_status" field.
func ConversionStatusNotIn ¶
ConversionStatusNotIn applies the NotIn predicate on the "conversion_status" field.
func ConversionStatusNotNil ¶
ConversionStatusNotNil applies the NotNil predicate on the "conversion_status" field.
func Country ¶
Country applies equality check predicate on the "country" field. It's identical to CountryEQ.
func CountryContains ¶
CountryContains applies the Contains predicate on the "country" field.
func CountryContainsFold ¶
CountryContainsFold applies the ContainsFold predicate on the "country" field.
func CountryEqualFold ¶
CountryEqualFold applies the EqualFold predicate on the "country" field.
func CountryGTE ¶
CountryGTE applies the GTE predicate on the "country" field.
func CountryHasPrefix ¶
CountryHasPrefix applies the HasPrefix predicate on the "country" field.
func CountryHasSuffix ¶
CountryHasSuffix applies the HasSuffix predicate on the "country" field.
func CountryIsNil ¶
CountryIsNil applies the IsNil predicate on the "country" field.
func CountryLTE ¶
CountryLTE applies the LTE predicate on the "country" field.
func CountryNEQ ¶
CountryNEQ applies the NEQ predicate on the "country" field.
func CountryNotIn ¶
CountryNotIn applies the NotIn predicate on the "country" field.
func CountryNotNil ¶
CountryNotNil applies the NotNil predicate on the "country" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DeviceType ¶
DeviceType applies equality check predicate on the "device_type" field. It's identical to DeviceTypeEQ.
func DeviceTypeContains ¶
DeviceTypeContains applies the Contains predicate on the "device_type" field.
func DeviceTypeContainsFold ¶
DeviceTypeContainsFold applies the ContainsFold predicate on the "device_type" field.
func DeviceTypeEQ ¶
DeviceTypeEQ applies the EQ predicate on the "device_type" field.
func DeviceTypeEqualFold ¶
DeviceTypeEqualFold applies the EqualFold predicate on the "device_type" field.
func DeviceTypeGT ¶
DeviceTypeGT applies the GT predicate on the "device_type" field.
func DeviceTypeGTE ¶
DeviceTypeGTE applies the GTE predicate on the "device_type" field.
func DeviceTypeHasPrefix ¶
DeviceTypeHasPrefix applies the HasPrefix predicate on the "device_type" field.
func DeviceTypeHasSuffix ¶
DeviceTypeHasSuffix applies the HasSuffix predicate on the "device_type" field.
func DeviceTypeIn ¶
DeviceTypeIn applies the In predicate on the "device_type" field.
func DeviceTypeIsNil ¶
DeviceTypeIsNil applies the IsNil predicate on the "device_type" field.
func DeviceTypeLT ¶
DeviceTypeLT applies the LT predicate on the "device_type" field.
func DeviceTypeLTE ¶
DeviceTypeLTE applies the LTE predicate on the "device_type" field.
func DeviceTypeNEQ ¶
DeviceTypeNEQ applies the NEQ predicate on the "device_type" field.
func DeviceTypeNotIn ¶
DeviceTypeNotIn applies the NotIn predicate on the "device_type" field.
func DeviceTypeNotNil ¶
DeviceTypeNotNil applies the NotNil predicate on the "device_type" field.
func DurationMs ¶
DurationMs applies equality check predicate on the "duration_ms" field. It's identical to DurationMsEQ.
func DurationMsEQ ¶
DurationMsEQ applies the EQ predicate on the "duration_ms" field.
func DurationMsGT ¶
DurationMsGT applies the GT predicate on the "duration_ms" field.
func DurationMsGTE ¶
DurationMsGTE applies the GTE predicate on the "duration_ms" field.
func DurationMsIn ¶
DurationMsIn applies the In predicate on the "duration_ms" field.
func DurationMsLT ¶
DurationMsLT applies the LT predicate on the "duration_ms" field.
func DurationMsLTE ¶
DurationMsLTE applies the LTE predicate on the "duration_ms" field.
func DurationMsNEQ ¶
DurationMsNEQ applies the NEQ predicate on the "duration_ms" field.
func DurationMsNotIn ¶
DurationMsNotIn applies the NotIn predicate on the "duration_ms" field.
func EndedAt ¶
EndedAt applies equality check predicate on the "ended_at" field. It's identical to EndedAtEQ.
func EndedAtGTE ¶
EndedAtGTE applies the GTE predicate on the "ended_at" field.
func EndedAtIsNil ¶
EndedAtIsNil applies the IsNil predicate on the "ended_at" field.
func EndedAtLTE ¶
EndedAtLTE applies the LTE predicate on the "ended_at" field.
func EndedAtNEQ ¶
EndedAtNEQ applies the NEQ predicate on the "ended_at" field.
func EndedAtNotIn ¶
EndedAtNotIn applies the NotIn predicate on the "ended_at" field.
func EndedAtNotNil ¶
EndedAtNotNil applies the NotNil predicate on the "ended_at" field.
func EntryPage ¶
EntryPage applies equality check predicate on the "entry_page" field. It's identical to EntryPageEQ.
func EntryPageContains ¶
EntryPageContains applies the Contains predicate on the "entry_page" field.
func EntryPageContainsFold ¶
EntryPageContainsFold applies the ContainsFold predicate on the "entry_page" field.
func EntryPageEQ ¶
EntryPageEQ applies the EQ predicate on the "entry_page" field.
func EntryPageEqualFold ¶
EntryPageEqualFold applies the EqualFold predicate on the "entry_page" field.
func EntryPageGT ¶
EntryPageGT applies the GT predicate on the "entry_page" field.
func EntryPageGTE ¶
EntryPageGTE applies the GTE predicate on the "entry_page" field.
func EntryPageHasPrefix ¶
EntryPageHasPrefix applies the HasPrefix predicate on the "entry_page" field.
func EntryPageHasSuffix ¶
EntryPageHasSuffix applies the HasSuffix predicate on the "entry_page" field.
func EntryPageIn ¶
EntryPageIn applies the In predicate on the "entry_page" field.
func EntryPageIsNil ¶
EntryPageIsNil applies the IsNil predicate on the "entry_page" field.
func EntryPageLT ¶
EntryPageLT applies the LT predicate on the "entry_page" field.
func EntryPageLTE ¶
EntryPageLTE applies the LTE predicate on the "entry_page" field.
func EntryPageNEQ ¶
EntryPageNEQ applies the NEQ predicate on the "entry_page" field.
func EntryPageNotIn ¶
EntryPageNotIn applies the NotIn predicate on the "entry_page" field.
func EntryPageNotNil ¶
EntryPageNotNil applies the NotNil predicate on the "entry_page" field.
func EventCount ¶
EventCount applies equality check predicate on the "event_count" field. It's identical to EventCountEQ.
func EventCountEQ ¶
EventCountEQ applies the EQ predicate on the "event_count" field.
func EventCountGT ¶
EventCountGT applies the GT predicate on the "event_count" field.
func EventCountGTE ¶
EventCountGTE applies the GTE predicate on the "event_count" field.
func EventCountIn ¶
EventCountIn applies the In predicate on the "event_count" field.
func EventCountLT ¶
EventCountLT applies the LT predicate on the "event_count" field.
func EventCountLTE ¶
EventCountLTE applies the LTE predicate on the "event_count" field.
func EventCountNEQ ¶
EventCountNEQ applies the NEQ predicate on the "event_count" field.
func EventCountNotIn ¶
EventCountNotIn applies the NotIn predicate on the "event_count" field.
func ExitPage ¶
ExitPage applies equality check predicate on the "exit_page" field. It's identical to ExitPageEQ.
func ExitPageContains ¶
ExitPageContains applies the Contains predicate on the "exit_page" field.
func ExitPageContainsFold ¶
ExitPageContainsFold applies the ContainsFold predicate on the "exit_page" field.
func ExitPageEQ ¶
ExitPageEQ applies the EQ predicate on the "exit_page" field.
func ExitPageEqualFold ¶
ExitPageEqualFold applies the EqualFold predicate on the "exit_page" field.
func ExitPageGT ¶
ExitPageGT applies the GT predicate on the "exit_page" field.
func ExitPageGTE ¶
ExitPageGTE applies the GTE predicate on the "exit_page" field.
func ExitPageHasPrefix ¶
ExitPageHasPrefix applies the HasPrefix predicate on the "exit_page" field.
func ExitPageHasSuffix ¶
ExitPageHasSuffix applies the HasSuffix predicate on the "exit_page" field.
func ExitPageIn ¶
ExitPageIn applies the In predicate on the "exit_page" field.
func ExitPageIsNil ¶
ExitPageIsNil applies the IsNil predicate on the "exit_page" field.
func ExitPageLT ¶
ExitPageLT applies the LT predicate on the "exit_page" field.
func ExitPageLTE ¶
ExitPageLTE applies the LTE predicate on the "exit_page" field.
func ExitPageNEQ ¶
ExitPageNEQ applies the NEQ predicate on the "exit_page" field.
func ExitPageNotIn ¶
ExitPageNotIn applies the NotIn predicate on the "exit_page" field.
func ExitPageNotNil ¶
ExitPageNotNil applies the NotNil predicate on the "exit_page" field.
func HasJourney ¶
HasJourney applies the HasEdge predicate on the "journey" edge.
func HasJourneyWith ¶
HasJourneyWith applies the HasEdge predicate on the "journey" edge with a given conditions (other predicates).
func HasProject ¶
HasProject applies the HasEdge predicate on the "project" edge.
func HasProjectWith ¶
HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).
func JourneyID ¶
JourneyID applies equality check predicate on the "journey_id" field. It's identical to JourneyIDEQ.
func JourneyIDEQ ¶
JourneyIDEQ applies the EQ predicate on the "journey_id" field.
func JourneyIDIn ¶
JourneyIDIn applies the In predicate on the "journey_id" field.
func JourneyIDIsNil ¶
JourneyIDIsNil applies the IsNil predicate on the "journey_id" field.
func JourneyIDNEQ ¶
JourneyIDNEQ applies the NEQ predicate on the "journey_id" field.
func JourneyIDNotIn ¶
JourneyIDNotIn applies the NotIn predicate on the "journey_id" field.
func JourneyIDNotNil ¶
JourneyIDNotNil applies the NotNil predicate on the "journey_id" field.
func LastJourneyStepID ¶
LastJourneyStepID applies equality check predicate on the "last_journey_step_id" field. It's identical to LastJourneyStepIDEQ.
func LastJourneyStepIDContains ¶
LastJourneyStepIDContains applies the Contains predicate on the "last_journey_step_id" field.
func LastJourneyStepIDContainsFold ¶
LastJourneyStepIDContainsFold applies the ContainsFold predicate on the "last_journey_step_id" field.
func LastJourneyStepIDEQ ¶
LastJourneyStepIDEQ applies the EQ predicate on the "last_journey_step_id" field.
func LastJourneyStepIDEqualFold ¶
LastJourneyStepIDEqualFold applies the EqualFold predicate on the "last_journey_step_id" field.
func LastJourneyStepIDGT ¶
LastJourneyStepIDGT applies the GT predicate on the "last_journey_step_id" field.
func LastJourneyStepIDGTE ¶
LastJourneyStepIDGTE applies the GTE predicate on the "last_journey_step_id" field.
func LastJourneyStepIDHasPrefix ¶
LastJourneyStepIDHasPrefix applies the HasPrefix predicate on the "last_journey_step_id" field.
func LastJourneyStepIDHasSuffix ¶
LastJourneyStepIDHasSuffix applies the HasSuffix predicate on the "last_journey_step_id" field.
func LastJourneyStepIDIn ¶
LastJourneyStepIDIn applies the In predicate on the "last_journey_step_id" field.
func LastJourneyStepIDIsNil ¶
LastJourneyStepIDIsNil applies the IsNil predicate on the "last_journey_step_id" field.
func LastJourneyStepIDLT ¶
LastJourneyStepIDLT applies the LT predicate on the "last_journey_step_id" field.
func LastJourneyStepIDLTE ¶
LastJourneyStepIDLTE applies the LTE predicate on the "last_journey_step_id" field.
func LastJourneyStepIDNEQ ¶
LastJourneyStepIDNEQ applies the NEQ predicate on the "last_journey_step_id" field.
func LastJourneyStepIDNotIn ¶
LastJourneyStepIDNotIn applies the NotIn predicate on the "last_journey_step_id" field.
func LastJourneyStepIDNotNil ¶
LastJourneyStepIDNotNil applies the NotNil predicate on the "last_journey_step_id" field.
func OrgID ¶
OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.
func OrgIDNotIn ¶
OrgIDNotIn applies the NotIn predicate on the "org_id" field.
func OsContains ¶
OsContains applies the Contains predicate on the "os" field.
func OsContainsFold ¶
OsContainsFold applies the ContainsFold predicate on the "os" field.
func OsEqualFold ¶
OsEqualFold applies the EqualFold predicate on the "os" field.
func OsHasPrefix ¶
OsHasPrefix applies the HasPrefix predicate on the "os" field.
func OsHasSuffix ¶
OsHasSuffix applies the HasSuffix predicate on the "os" field.
func PageCount ¶
PageCount applies equality check predicate on the "page_count" field. It's identical to PageCountEQ.
func PageCountEQ ¶
PageCountEQ applies the EQ predicate on the "page_count" field.
func PageCountGT ¶
PageCountGT applies the GT predicate on the "page_count" field.
func PageCountGTE ¶
PageCountGTE applies the GTE predicate on the "page_count" field.
func PageCountIn ¶
PageCountIn applies the In predicate on the "page_count" field.
func PageCountLT ¶
PageCountLT applies the LT predicate on the "page_count" field.
func PageCountLTE ¶
PageCountLTE applies the LTE predicate on the "page_count" field.
func PageCountNEQ ¶
PageCountNEQ applies the NEQ predicate on the "page_count" field.
func PageCountNotIn ¶
PageCountNotIn applies the NotIn predicate on the "page_count" field.
func ProjectID ¶
ProjectID applies equality check predicate on the "project_id" field. It's identical to ProjectIDEQ.
func ProjectIDEQ ¶
ProjectIDEQ applies the EQ predicate on the "project_id" field.
func ProjectIDIn ¶
ProjectIDIn applies the In predicate on the "project_id" field.
func ProjectIDNEQ ¶
ProjectIDNEQ applies the NEQ predicate on the "project_id" field.
func ProjectIDNotIn ¶
ProjectIDNotIn applies the NotIn predicate on the "project_id" field.
func Region ¶
Region applies equality check predicate on the "region" field. It's identical to RegionEQ.
func RegionContains ¶
RegionContains applies the Contains predicate on the "region" field.
func RegionContainsFold ¶
RegionContainsFold applies the ContainsFold predicate on the "region" field.
func RegionEqualFold ¶
RegionEqualFold applies the EqualFold predicate on the "region" field.
func RegionHasPrefix ¶
RegionHasPrefix applies the HasPrefix predicate on the "region" field.
func RegionHasSuffix ¶
RegionHasSuffix applies the HasSuffix predicate on the "region" field.
func RegionIsNil ¶
RegionIsNil applies the IsNil predicate on the "region" field.
func RegionNotIn ¶
RegionNotIn applies the NotIn predicate on the "region" field.
func RegionNotNil ¶
RegionNotNil applies the NotNil predicate on the "region" field.
func SessionID ¶
SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.
func SessionIDContains ¶
SessionIDContains applies the Contains predicate on the "session_id" field.
func SessionIDContainsFold ¶
SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.
func SessionIDEQ ¶
SessionIDEQ applies the EQ predicate on the "session_id" field.
func SessionIDEqualFold ¶
SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.
func SessionIDGT ¶
SessionIDGT applies the GT predicate on the "session_id" field.
func SessionIDGTE ¶
SessionIDGTE applies the GTE predicate on the "session_id" field.
func SessionIDHasPrefix ¶
SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.
func SessionIDHasSuffix ¶
SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.
func SessionIDIn ¶
SessionIDIn applies the In predicate on the "session_id" field.
func SessionIDLT ¶
SessionIDLT applies the LT predicate on the "session_id" field.
func SessionIDLTE ¶
SessionIDLTE applies the LTE predicate on the "session_id" field.
func SessionIDNEQ ¶
SessionIDNEQ applies the NEQ predicate on the "session_id" field.
func SessionIDNotIn ¶
SessionIDNotIn applies the NotIn predicate on the "session_id" field.
func StartedAt ¶
StartedAt applies equality check predicate on the "started_at" field. It's identical to StartedAtEQ.
func StartedAtEQ ¶
StartedAtEQ applies the EQ predicate on the "started_at" field.
func StartedAtGT ¶
StartedAtGT applies the GT predicate on the "started_at" field.
func StartedAtGTE ¶
StartedAtGTE applies the GTE predicate on the "started_at" field.
func StartedAtIn ¶
StartedAtIn applies the In predicate on the "started_at" field.
func StartedAtLT ¶
StartedAtLT applies the LT predicate on the "started_at" field.
func StartedAtLTE ¶
StartedAtLTE applies the LTE predicate on the "started_at" field.
func StartedAtNEQ ¶
StartedAtNEQ applies the NEQ predicate on the "started_at" field.
func StartedAtNotIn ¶
StartedAtNotIn applies the NotIn predicate on the "started_at" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UserAgent ¶
UserAgent applies equality check predicate on the "user_agent" field. It's identical to UserAgentEQ.
func UserAgentContains ¶
UserAgentContains applies the Contains predicate on the "user_agent" field.
func UserAgentContainsFold ¶
UserAgentContainsFold applies the ContainsFold predicate on the "user_agent" field.
func UserAgentEQ ¶
UserAgentEQ applies the EQ predicate on the "user_agent" field.
func UserAgentEqualFold ¶
UserAgentEqualFold applies the EqualFold predicate on the "user_agent" field.
func UserAgentGT ¶
UserAgentGT applies the GT predicate on the "user_agent" field.
func UserAgentGTE ¶
UserAgentGTE applies the GTE predicate on the "user_agent" field.
func UserAgentHasPrefix ¶
UserAgentHasPrefix applies the HasPrefix predicate on the "user_agent" field.
func UserAgentHasSuffix ¶
UserAgentHasSuffix applies the HasSuffix predicate on the "user_agent" field.
func UserAgentIn ¶
UserAgentIn applies the In predicate on the "user_agent" field.
func UserAgentIsNil ¶
UserAgentIsNil applies the IsNil predicate on the "user_agent" field.
func UserAgentLT ¶
UserAgentLT applies the LT predicate on the "user_agent" field.
func UserAgentLTE ¶
UserAgentLTE applies the LTE predicate on the "user_agent" field.
func UserAgentNEQ ¶
UserAgentNEQ applies the NEQ predicate on the "user_agent" field.
func UserAgentNotIn ¶
UserAgentNotIn applies the NotIn predicate on the "user_agent" field.
func UserAgentNotNil ¶
UserAgentNotNil applies the NotNil predicate on the "user_agent" field.
func UserID ¶
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDContains ¶
UserIDContains applies the Contains predicate on the "user_id" field.
func UserIDContainsFold ¶
UserIDContainsFold applies the ContainsFold predicate on the "user_id" field.
func UserIDEqualFold ¶
UserIDEqualFold applies the EqualFold predicate on the "user_id" field.
func UserIDHasPrefix ¶
UserIDHasPrefix applies the HasPrefix predicate on the "user_id" field.
func UserIDHasSuffix ¶
UserIDHasSuffix applies the HasSuffix predicate on the "user_id" field.
func UserIDIsNil ¶
UserIDIsNil applies the IsNil predicate on the "user_id" field.
func UserIDNotIn ¶
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func UserIDNotNil ¶
UserIDNotNil applies the NotNil predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Session queries.
func ByBrowser ¶
func ByBrowser(opts ...sql.OrderTermOption) OrderOption
ByBrowser orders the results by the browser field.
func ByCity ¶
func ByCity(opts ...sql.OrderTermOption) OrderOption
ByCity orders the results by the city field.
func ByConversionStatus ¶
func ByConversionStatus(opts ...sql.OrderTermOption) OrderOption
ByConversionStatus orders the results by the conversion_status field.
func ByCountry ¶
func ByCountry(opts ...sql.OrderTermOption) OrderOption
ByCountry orders the results by the country field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDeviceType ¶
func ByDeviceType(opts ...sql.OrderTermOption) OrderOption
ByDeviceType orders the results by the device_type field.
func ByDurationMs ¶
func ByDurationMs(opts ...sql.OrderTermOption) OrderOption
ByDurationMs orders the results by the duration_ms field.
func ByEndedAt ¶
func ByEndedAt(opts ...sql.OrderTermOption) OrderOption
ByEndedAt orders the results by the ended_at field.
func ByEntryPage ¶
func ByEntryPage(opts ...sql.OrderTermOption) OrderOption
ByEntryPage orders the results by the entry_page field.
func ByEventCount ¶
func ByEventCount(opts ...sql.OrderTermOption) OrderOption
ByEventCount orders the results by the event_count field.
func ByExitPage ¶
func ByExitPage(opts ...sql.OrderTermOption) OrderOption
ByExitPage orders the results by the exit_page field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByJourneyField ¶
func ByJourneyField(field string, opts ...sql.OrderTermOption) OrderOption
ByJourneyField orders the results by journey field.
func ByJourneyID ¶
func ByJourneyID(opts ...sql.OrderTermOption) OrderOption
ByJourneyID orders the results by the journey_id field.
func ByLastJourneyStepID ¶
func ByLastJourneyStepID(opts ...sql.OrderTermOption) OrderOption
ByLastJourneyStepID orders the results by the last_journey_step_id field.
func ByOrgID ¶
func ByOrgID(opts ...sql.OrderTermOption) OrderOption
ByOrgID orders the results by the org_id field.
func ByOs ¶
func ByOs(opts ...sql.OrderTermOption) OrderOption
ByOs orders the results by the os field.
func ByPageCount ¶
func ByPageCount(opts ...sql.OrderTermOption) OrderOption
ByPageCount orders the results by the page_count field.
func ByProjectField ¶
func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
ByProjectField orders the results by project field.
func ByProjectID ¶
func ByProjectID(opts ...sql.OrderTermOption) OrderOption
ByProjectID orders the results by the project_id field.
func ByRegion ¶
func ByRegion(opts ...sql.OrderTermOption) OrderOption
ByRegion orders the results by the region field.
func BySessionID ¶
func BySessionID(opts ...sql.OrderTermOption) OrderOption
BySessionID orders the results by the session_id field.
func ByStartedAt ¶
func ByStartedAt(opts ...sql.OrderTermOption) OrderOption
ByStartedAt orders the results by the started_at field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUserAgent ¶
func ByUserAgent(opts ...sql.OrderTermOption) OrderOption
ByUserAgent orders the results by the user_agent field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.